@@ -6,7 +6,9 @@ from datadog_api_client.v1 import ApiClient, Configuration
 from datadog_api_client.v1.api.dashboard_lists_api import DashboardListsApi
 from datadog_api_client.v1.model.dashboard_list import DashboardList
 
-body = DashboardList(name="Example-Create_a_dashboard_list_returns_OK_response")
+body = DashboardList(
+    name="Example-Create_a_dashboard_list_returns_OK_response",
+)
 
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
