@@ -12,6 +12,8 @@ DASHBOARD_LIST_ID = environ["DASHBOARD_LIST_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = DashboardListsApi(api_client)
-    response = api_instance.get_dashboard_list(list_id=int(DASHBOARD_LIST_ID))
+    response = api_instance.get_dashboard_list(
+        list_id=int(DASHBOARD_LIST_ID),
+    )
 
     print(response)
