@@ -10,7 +10,9 @@ from datadog_api_client.v1.model.dashboard_list import DashboardList
 # there is a valid "dashboard_list" in the system
 DASHBOARD_LIST_ID = environ["DASHBOARD_LIST_ID"]
 
-body = DashboardList(name="updated Example-Update_a_dashboard_list_returns_OK_response")
+body = DashboardList(
+    name="updated Example-Update_a_dashboard_list_returns_OK_response",
+)
 
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
