@@ -16,11 +16,17 @@ body = Dashboard(
     description="",
     widgets=[
         Widget(
-            layout=WidgetLayout(x=0, y=0, width=12, height=12),
-            definition=IFrameWidgetDefinition(
-                type=IFrameWidgetDefinitionType("iframe"), url="https://docs.datadoghq.com/api/latest/"
+            layout=WidgetLayout(
+                x=0,
+                y=0,
+                width=12,
+                height=12,
             ),
-        )
+            definition=IFrameWidgetDefinition(
+                type=IFrameWidgetDefinitionType("iframe"),
+                url="https://docs.datadoghq.com/api/latest/",
+            ),
+        ),
     ],
     template_variables=[],
     layout_type=DashboardLayoutType("free"),
