@@ -8,6 +8,8 @@ from datadog_api_client.v1.api.dashboards_api import DashboardsApi
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = DashboardsApi(api_client)
-    response = api_instance.list_dashboards(filter_shared=False)
+    response = api_instance.list_dashboards(
+        filter_shared=False,
+    )
 
     print(response)
