@@ -12,4 +12,6 @@ DOWNTIME_ID = environ["DOWNTIME_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = DowntimesApi(api_client)
-    api_instance.cancel_downtime(downtime_id=int(DOWNTIME_ID))
+    api_instance.cancel_downtime(
+        downtime_id=int(DOWNTIME_ID),
+    )
