@@ -13,11 +13,19 @@ body = Downtime(
     message="Example-Schedule_a_downtime_returns_OK_response",
     start=int(datetime.now().timestamp()),
     timezone="Etc/UTC",
-    scope=["test:examplescheduleadowntimereturnsokresponse"],
+    scope=[
+        "test:examplescheduleadowntimereturnsokresponse",
+    ],
     recurrence=DowntimeRecurrence(
         type="weeks",
         period=1,
-        week_days=["Mon", "Tue", "Wed", "Thu", "Fri"],
+        week_days=[
+            "Mon",
+            "Tue",
+            "Wed",
+            "Thu",
+            "Fri",
+        ],
         until_date=int((datetime.now() + relativedelta(days=21)).timestamp()),
     ),
 )
