@@ -12,9 +12,20 @@ from datadog_api_client.v1.model.downtime_recurrence import DowntimeRecurrence
 body = Downtime(
     message="Example-Schedule_a_downtime_with_until_occurrences",
     recurrence=DowntimeRecurrence(
-        period=1, type="weeks", until_occurrences=3, week_days=["Mon", "Tue", "Wed", "Thu", "Fri"]
+        period=1,
+        type="weeks",
+        until_occurrences=3,
+        week_days=[
+            "Mon",
+            "Tue",
+            "Wed",
+            "Thu",
+            "Fri",
+        ],
     ),
-    scope=["*"],
+    scope=[
+        "*",
+    ],
     start=int(datetime.now().timestamp()),
     end=int((datetime.now() + relativedelta(hours=1)).timestamp()),
     timezone="Etc/UTC",
