@@ -15,9 +15,17 @@ body = Downtime(
         period=1,
         type="weeks",
         until_date=int((datetime.now() + relativedelta(days=21)).timestamp()),
-        week_days=["Mon", "Tue", "Wed", "Thu", "Fri"],
+        week_days=[
+            "Mon",
+            "Tue",
+            "Wed",
+            "Thu",
+            "Fri",
+        ],
     ),
-    scope=["*"],
+    scope=[
+        "*",
+    ],
     start=int(datetime.now().timestamp()),
     end=int((datetime.now() + relativedelta(hours=1)).timestamp()),
     timezone="Etc/UTC",
