@@ -11,8 +11,13 @@ from datadog_api_client.v1.model.downtime_recurrence import DowntimeRecurrence
 
 body = Downtime(
     message="Example-Schedule_a_downtime_once_a_year",
-    recurrence=DowntimeRecurrence(period=1, type="years"),
-    scope=["*"],
+    recurrence=DowntimeRecurrence(
+        period=1,
+        type="years",
+    ),
+    scope=[
+        "*",
+    ],
     start=int(datetime.now().timestamp()),
     end=int((datetime.now() + relativedelta(hours=1)).timestamp()),
     timezone="Etc/UTC",
