@@ -9,7 +9,9 @@ from datadog_api_client.v1.model.event_create_request import EventCreateRequest
 body = EventCreateRequest(
     title="Example-Post_an_event_returns_OK_response",
     text="A text message.",
-    tags=["test:ExamplePostaneventreturnsOKresponse"],
+    tags=[
+        "test:ExamplePostaneventreturnsOKresponse",
+    ],
 )
 
 configuration = Configuration()
