@@ -8,6 +8,8 @@ from datadog_api_client.v1.api.hosts_api import HostsApi
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = HostsApi(api_client)
-    response = api_instance.list_hosts(filter="env:ci")
+    response = api_instance.list_hosts(
+        filter="env:ci",
+    )
 
     print(response)
