@@ -8,6 +8,8 @@ from datadog_api_client.v1.api.hosts_api import HostsApi
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = HostsApi(api_client)
-    response = api_instance.list_hosts(include_hosts_metadata=True)
+    response = api_instance.list_hosts(
+        include_hosts_metadata=True,
+    )
 
     print(response)
