@@ -14,10 +14,19 @@ body = MetricsPayload(
         Series(
             metric="system.load.1",
             type="gauge",
-            points=[Point([datetime.now().timestamp(), 1.1])],
-            tags=["test:ExampleSubmitmetricsreturnsPayloadacceptedresponse"],
-        )
-    ]
+            points=[
+                Point(
+                    [
+                        datetime.now().timestamp(),
+                        1.1,
+                    ]
+                ),
+            ],
+            tags=[
+                "test:ExampleSubmitmetricsreturnsPayloadacceptedresponse",
+            ],
+        ),
+    ],
 )
 
 configuration = Configuration()
