@@ -12,6 +12,10 @@ MONITOR_ID = environ["MONITOR_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = MonitorsApi(api_client)
-    response = api_instance.check_can_delete_monitor(monitor_ids=["MONITOR_ID"])
+    response = api_instance.check_can_delete_monitor(
+        monitor_ids=[
+            int(MONITOR_ID),
+        ],
+    )
 
     print(response)
