@@ -13,17 +13,28 @@ from datadog_api_client.v1.model.slo_type import SLOType
 body = ServiceLevelObjectiveRequest(
     type=SLOType("metric"),
     description="string",
-    groups=["env:test", "role:mysql"],
+    groups=[
+        "env:test",
+        "role:mysql",
+    ],
     monitor_ids=[],
     name="Example-Create_an_SLO_object_returns_OK_response",
     query=ServiceLevelObjectiveQuery(
-        denominator="sum:httpservice.hits{!code:3xx}.as_count()", numerator="sum:httpservice.hits{code:2xx}.as_count()"
+        denominator="sum:httpservice.hits{!code:3xx}.as_count()",
+        numerator="sum:httpservice.hits{code:2xx}.as_count()",
     ),
-    tags=["env:prod", "app:core"],
+    tags=[
+        "env:prod",
+        "app:core",
+    ],
     thresholds=[
         SLOThreshold(
-            target=95.0, target_display="95.0", timeframe=SLOTimeframe("7d"), warning=98.0, warning_display="98.0"
-        )
+            target=95.0,
+            target_display="95.0",
+            timeframe=SLOTimeframe("7d"),
+            warning=98.0,
+            warning_display="98.0",
+        ),
     ],
 )
 
