@@ -12,6 +12,8 @@ SLO_DATA_0_ID = environ["SLO_DATA_0_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = ServiceLevelObjectivesApi(api_client)
-    response = api_instance.delete_slo(slo_id=SLO_DATA_0_ID)
+    response = api_instance.delete_slo(
+        slo_id=SLO_DATA_0_ID,
+    )
 
     print(response)
