@@ -7,7 +7,8 @@ from datadog_api_client.v1.api.webhooks_integration_api import WebhooksIntegrati
 from datadog_api_client.v1.model.webhooks_integration import WebhooksIntegration
 
 body = WebhooksIntegration(
-    name="Example-Create_a_webhooks_integration_returns_OK_response", url="https://example.com/webhook"
+    name="Example-Create_a_webhooks_integration_returns_OK_response",
+    url="https://example.com/webhook",
 )
 
 configuration = Configuration()
