@@ -12,6 +12,8 @@ WEBHOOK_NAME = environ["WEBHOOK_NAME"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = WebhooksIntegrationApi(api_client)
-    response = api_instance.get_webhooks_integration(webhook_name=WEBHOOK_NAME)
+    response = api_instance.get_webhooks_integration(
+        webhook_name=WEBHOOK_NAME,
+    )
 
     print(response)
