@@ -12,7 +12,9 @@ from datadog_api_client.v1.model.webhooks_integration_custom_variable_update_req
 # there is a valid "webhook_custom_variable" in the system
 WEBHOOK_CUSTOM_VARIABLE_NAME = environ["WEBHOOK_CUSTOM_VARIABLE_NAME"]
 
-body = WebhooksIntegrationCustomVariableUpdateRequest(value="variable-updated")
+body = WebhooksIntegrationCustomVariableUpdateRequest(
+    value="variable-updated",
+)
 
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
