@@ -3,11 +3,11 @@ List all AuthN Mappings returns "OK" response
 """
 
 from datadog_api_client.v2 import ApiClient, Configuration
-from datadog_api_client.v2.api.auth_n_mappings_api import AuthNMappingsApi
+from datadog_api_client.v2.api.authn_mappings_api import AuthNMappingsApi
 
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = AuthNMappingsApi(api_client)
-    response = api_instance.list_auth_n_mappings()
+    response = api_instance.list_authn_mappings()
 
     print(response)
