@@ -12,6 +12,8 @@ AGENT_RULE_DATA_ID = environ["AGENT_RULE_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = CloudWorkloadSecurityApi(api_client)
-    response = api_instance.get_cloud_workload_security_agent_rule(agent_rule_id=AGENT_RULE_DATA_ID)
+    response = api_instance.get_cloud_workload_security_agent_rule(
+        agent_rule_id=AGENT_RULE_DATA_ID,
+    )
 
     print(response)
