@@ -13,6 +13,8 @@ configuration = Configuration()
 configuration.unstable_operations["get_incident_service"] = True
 with ApiClient(configuration) as api_client:
     api_instance = IncidentServicesApi(api_client)
-    response = api_instance.get_incident_service(service_id=SERVICE_DATA_ID)
+    response = api_instance.get_incident_service(
+        service_id=SERVICE_DATA_ID,
+    )
 
     print(response)
