@@ -13,6 +13,8 @@ configuration = Configuration()
 configuration.unstable_operations["get_incident_team"] = True
 with ApiClient(configuration) as api_client:
     api_instance = IncidentTeamsApi(api_client)
-    response = api_instance.get_incident_team(team_id=TEAM_DATA_ID)
+    response = api_instance.get_incident_team(
+        team_id=TEAM_DATA_ID,
+    )
 
     print(response)
