@@ -12,8 +12,10 @@ from datadog_api_client.v2.model.api_keys_type import APIKeysType
 body = APIKeyCreateRequest(
     data=APIKeyCreateData(
         type=APIKeysType("api_keys"),
-        attributes=APIKeyCreateAttributes(name="Example-Create_an_API_key_returns_Created_response"),
-    )
+        attributes=APIKeyCreateAttributes(
+            name="Example-Create_an_API_key_returns_Created_response",
+        ),
+    ),
 )
 
 configuration = Configuration()
