@@ -13,9 +13,9 @@ body = ApplicationKeyCreateRequest(
     data=ApplicationKeyCreateData(
         type=ApplicationKeysType("application_keys"),
         attributes=ApplicationKeyCreateAttributes(
-            name="Example-Create_an_Application_key_for_current_user_returns_Created_response"
+            name="Example-Create_an_Application_key_for_current_user_returns_Created_response",
         ),
-    )
+    ),
 )
 
 configuration = Configuration()
