@@ -14,9 +14,13 @@ body = ApplicationKeyCreateRequest(
         type=ApplicationKeysType("application_keys"),
         attributes=ApplicationKeyCreateAttributes(
             name="Example-Create_an_Application_key_with_scopes_for_current_user_returns_Created_response",
-            scopes=["dashboards_read", "dashboards_write", "dashboards_public_share"],
+            scopes=[
+                "dashboards_read",
+                "dashboards_write",
+                "dashboards_public_share",
+            ],
         ),
-    )
+    ),
 )
 
 configuration = Configuration()
