@@ -12,4 +12,6 @@ APPLICATION_KEY_DATA_ID = environ["APPLICATION_KEY_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = KeyManagementApi(api_client)
-    api_instance.delete_application_key(app_key_id=APPLICATION_KEY_DATA_ID)
+    api_instance.delete_application_key(
+        app_key_id=APPLICATION_KEY_DATA_ID,
+    )
