@@ -12,6 +12,8 @@ API_KEY_DATA_ID = environ["API_KEY_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = KeyManagementApi(api_client)
-    response = api_instance.get_api_key(api_key_id=API_KEY_DATA_ID)
+    response = api_instance.get_api_key(
+        api_key_id=API_KEY_DATA_ID,
+    )
 
     print(response)
