@@ -12,6 +12,8 @@ APPLICATION_KEY_DATA_ID = environ["APPLICATION_KEY_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = KeyManagementApi(api_client)
-    response = api_instance.get_current_user_application_key(app_key_id=APPLICATION_KEY_DATA_ID)
+    response = api_instance.get_current_user_application_key(
+        app_key_id=APPLICATION_KEY_DATA_ID,
+    )
 
     print(response)
