@@ -12,6 +12,8 @@ LOGS_METRIC_DATA_ID = environ["LOGS_METRIC_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = LogsMetricsApi(api_client)
-    response = api_instance.get_logs_metric(metric_id=LOGS_METRIC_DATA_ID)
+    response = api_instance.get_logs_metric(
+        metric_id=LOGS_METRIC_DATA_ID,
+    )
 
     print(response)
