@@ -7,7 +7,16 @@ from datadog_api_client.v2.api.logs_api import LogsApi
 from datadog_api_client.v2.model.logs_aggregate_request import LogsAggregateRequest
 from datadog_api_client.v2.model.logs_query_filter import LogsQueryFilter
 
-body = LogsAggregateRequest(filter=LogsQueryFilter(_from="now-15m", indexes=["main"], query="*", to="now"))
+body = LogsAggregateRequest(
+    filter=LogsQueryFilter(
+        _from="now-15m",
+        indexes=[
+            "main",
+        ],
+        query="*",
+        to="now",
+    ),
+)
 
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
