@@ -11,14 +11,20 @@ from datadog_api_client.v2.model.logs_sort import LogsSort
 
 body = LogsListRequest(
     filter=LogsQueryFilter(
-        query="datadog-agent", indexes=["main"], _from="2020-09-17T11:48:36+01:00", to="2020-09-17T12:48:36+01:00"
+        query="datadog-agent",
+        indexes=[
+            "main",
+        ],
+        _from="2020-09-17T11:48:36+01:00",
+        to="2020-09-17T12:48:36+01:00",
     ),
     sort=LogsSort("timestamp"),
-    page=LogsListRequestPage(limit=5),
+    page=LogsListRequestPage(
+        limit=5,
+    ),
 )
 
 configuration = Configuration()
-configuration.unstable_operations["list_logs"] = True
 with ApiClient(configuration) as api_client:
     api_instance = LogsApi(api_client)
     response = api_instance.list_logs(body=body)
