@@ -4,6 +4,7 @@ Send deflate logs returns "Request accepted for processing (always 202 empty JSO
 
 from datadog_api_client.v2 import ApiClient, Configuration
 from datadog_api_client.v2.api.logs_api import LogsApi
+from datadog_api_client.v2.model.content_encoding import ContentEncoding
 from datadog_api_client.v2.model.http_log import HTTPLog
 from datadog_api_client.v2.model.http_log_item import HTTPLogItem
 
@@ -15,13 +16,13 @@ body = HTTPLog(
             hostname="i-012345678",
             message="2019-11-19T14:37:58,995 INFO [process.name][20081] Hello World",
             service="payment",
-        )
+        ),
     ]
 )
 
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = LogsApi(api_client)
-    response = api_instance.submit_log(content_encoding="deflate", body=body)
+    response = api_instance.submit_log(content_encoding=ContentEncoding("deflate"), body=body)
 
     print(response)
