@@ -12,4 +12,6 @@ SECURITY_FILTER_DATA_ID = environ["SECURITY_FILTER_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = SecurityMonitoringApi(api_client)
-    api_instance.delete_security_filter(security_filter_id=SECURITY_FILTER_DATA_ID)
+    api_instance.delete_security_filter(
+        security_filter_id=SECURITY_FILTER_DATA_ID,
+    )
