@@ -12,4 +12,6 @@ SECURITY_RULE_ID = environ["SECURITY_RULE_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = SecurityMonitoringApi(api_client)
-    api_instance.delete_security_monitoring_rule(rule_id=SECURITY_RULE_ID)
+    api_instance.delete_security_monitoring_rule(
+        rule_id=SECURITY_RULE_ID,
+    )
