@@ -12,6 +12,8 @@ SECURITY_FILTER_DATA_ID = environ["SECURITY_FILTER_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = SecurityMonitoringApi(api_client)
-    response = api_instance.get_security_filter(security_filter_id=SECURITY_FILTER_DATA_ID)
+    response = api_instance.get_security_filter(
+        security_filter_id=SECURITY_FILTER_DATA_ID,
+    )
 
     print(response)
