@@ -16,7 +16,8 @@ configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = ServiceAccountsApi(api_client)
     response = api_instance.get_service_account_application_key(
-        service_account_id=SERVICE_ACCOUNT_USER_DATA_ID, app_key_id=SERVICE_ACCOUNT_APPLICATION_KEY_DATA_ID
+        service_account_id=SERVICE_ACCOUNT_USER_DATA_ID,
+        app_key_id=SERVICE_ACCOUNT_APPLICATION_KEY_DATA_ID,
     )
 
     print(response)
