@@ -12,6 +12,8 @@ SERVICE_ACCOUNT_USER_DATA_ID = environ["SERVICE_ACCOUNT_USER_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = ServiceAccountsApi(api_client)
-    response = api_instance.list_service_account_application_keys(service_account_id=SERVICE_ACCOUNT_USER_DATA_ID)
+    response = api_instance.list_service_account_application_keys(
+        service_account_id=SERVICE_ACCOUNT_USER_DATA_ID,
+    )
 
     print(response)
