@@ -13,9 +13,10 @@ body = UserCreateRequest(
     data=UserCreateData(
         type=UsersType("users"),
         attributes=UserCreateAttributes(
-            name="Datadog API Client Python", email="Example-Create_a_user_returns_OK_response@datadoghq.com"
+            name="Datadog API Client Python",
+            email="Example-Create_a_user_returns_OK_response@datadoghq.com",
         ),
-    )
+    ),
 )
 
 configuration = Configuration()
