@@ -12,4 +12,6 @@ USER_DATA_ID = environ["USER_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = UsersApi(api_client)
-    api_instance.disable_user(user_id=USER_DATA_ID)
+    api_instance.disable_user(
+        user_id=USER_DATA_ID,
+    )
