@@ -12,6 +12,8 @@ USER_INVITATION_ID = environ["USER_INVITATION_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = UsersApi(api_client)
-    response = api_instance.get_invitation(user_invitation_uuid=USER_INVITATION_ID)
+    response = api_instance.get_invitation(
+        user_invitation_uuid=USER_INVITATION_ID,
+    )
 
     print(response)
