@@ -12,6 +12,8 @@ USER_DATA_ID = environ["USER_DATA_ID"]
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = UsersApi(api_client)
-    response = api_instance.get_user(user_id=USER_DATA_ID)
+    response = api_instance.get_user(
+        user_id=USER_DATA_ID,
+    )
 
     print(response)
