@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.aws_account_and_lambda_request import AWSAccountAndLambdaRequest
 from datadog_api_client.v1.model.aws_logs_list_response import AWSLogsListResponse
 from datadog_api_client.v1.model.aws_logs_async_response import AWSLogsAsyncResponse
@@ -24,6 +24,7 @@ class AWSLogsIntegrationApi:
                 "endpoint_path": "/api/v1/integration/aws/logs/check_async",
                 "operation_id": "check_aws_logs_lambda_async",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -44,6 +45,7 @@ class AWSLogsIntegrationApi:
                 "endpoint_path": "/api/v1/integration/aws/logs/services_async",
                 "operation_id": "check_aws_logs_services_async",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -64,6 +66,7 @@ class AWSLogsIntegrationApi:
                 "endpoint_path": "/api/v1/integration/aws/logs",
                 "operation_id": "create_aws_lambda_arn",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -84,6 +87,7 @@ class AWSLogsIntegrationApi:
                 "endpoint_path": "/api/v1/integration/aws/logs",
                 "operation_id": "delete_aws_lambda_arn",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -104,6 +108,7 @@ class AWSLogsIntegrationApi:
                 "endpoint_path": "/api/v1/integration/aws/logs/services",
                 "operation_id": "enable_aws_log_services",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -124,6 +129,7 @@ class AWSLogsIntegrationApi:
                 "endpoint_path": "/api/v1/integration/aws/logs",
                 "operation_id": "list_aws_logs_integrations",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={},
@@ -141,6 +147,7 @@ class AWSLogsIntegrationApi:
                 "endpoint_path": "/api/v1/integration/aws/logs/services",
                 "operation_id": "list_aws_logs_services",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={},
