@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.api_key_list_response import ApiKeyListResponse
 from datadog_api_client.v1.model.api_key_response import ApiKeyResponse
 from datadog_api_client.v1.model.api_key import ApiKey
@@ -25,6 +25,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/api_key",
                 "operation_id": "create_api_key",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -45,6 +46,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/application_key",
                 "operation_id": "create_application_key",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -65,6 +67,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/api_key/{key}",
                 "operation_id": "delete_api_key",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -89,6 +92,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/application_key/{key}",
                 "operation_id": "delete_application_key",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -113,6 +117,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/api_key/{key}",
                 "operation_id": "get_api_key",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -137,6 +142,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/application_key/{key}",
                 "operation_id": "get_application_key",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -161,6 +167,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/api_key",
                 "operation_id": "list_api_keys",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={},
@@ -178,6 +185,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/application_key",
                 "operation_id": "list_application_keys",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={},
@@ -195,6 +203,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/api_key/{key}",
                 "operation_id": "update_api_key",
                 "http_method": "PUT",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -221,6 +230,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v1/application_key/{key}",
                 "operation_id": "update_application_key",
                 "http_method": "PUT",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -251,7 +261,6 @@ class KeyManagementApi:
         >>> thread = api.create_api_key(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: ApiKey
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -295,7 +304,6 @@ class KeyManagementApi:
         >>> thread = api.create_application_key(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: ApplicationKey
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -597,7 +605,6 @@ class KeyManagementApi:
 
         :param key: The specific API key you are working with.
         :type key: str
-
         :type body: ApiKey
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -645,7 +652,6 @@ class KeyManagementApi:
 
         :param key: The specific APP key you are working with.
         :type key: str
-
         :type body: ApplicationKey
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
