@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.metrics_list_response import MetricsListResponse
 from datadog_api_client.v1.model.metric_metadata import MetricMetadata
 from datadog_api_client.v1.model.metrics_query_response import MetricsQueryResponse
@@ -26,6 +26,7 @@ class MetricsApi:
                 "endpoint_path": "/api/v1/metrics/{metric_name}",
                 "operation_id": "get_metric_metadata",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -50,6 +51,7 @@ class MetricsApi:
                 "endpoint_path": "/api/v1/metrics",
                 "operation_id": "list_active_metrics",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -84,6 +86,7 @@ class MetricsApi:
                 "endpoint_path": "/api/v1/search",
                 "operation_id": "list_metrics",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -108,6 +111,7 @@ class MetricsApi:
                 "endpoint_path": "/api/v1/query",
                 "operation_id": "query_metrics",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -144,6 +148,7 @@ class MetricsApi:
                 "endpoint_path": "/api/v1/series",
                 "operation_id": "submit_metrics",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -169,6 +174,7 @@ class MetricsApi:
                 "endpoint_path": "/api/v1/metrics/{metric_name}",
                 "operation_id": "update_metric_metadata",
                 "http_method": "PUT",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -293,7 +299,7 @@ class MetricsApi:
         >>> thread = api.list_metrics(q, async_req=True)
         >>> result = thread.get()
 
-        :param q: Query string to search metrics upon. Must be prefixed with `metrics:`.
+        :param q: Query string to search metrics upon. Can optionally be prefixed with `metrics:`.
         :type q: str
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -388,7 +394,7 @@ class MetricsApi:
 
         - 64 bits for the timestamp
         - 32 bits for the value
-        - 20 bytes for the metric names
+        - 40 bytes for the metric names
         - 50 bytes for the timeseries
         - The full payload is approximately 100 bytes. However, with the DogStatsD API,
         compression is applied, which reduces the payload size.
@@ -399,7 +405,6 @@ class MetricsApi:
         >>> thread = api.submit_metrics(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: MetricsPayload
         :param content_encoding: HTTP header used to compress the media-type.
         :type content_encoding: MetricContentEncoding, optional
