@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.monitor import Monitor
 from datadog_api_client.v1.model.check_can_delete_monitor_response import CheckCanDeleteMonitorResponse
 from datadog_api_client.v1.model.monitor_group_search_response import MonitorGroupSearchResponse
@@ -25,6 +25,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor/can_delete",
                 "operation_id": "check_can_delete_monitor",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -50,6 +51,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor",
                 "operation_id": "create_monitor",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -70,6 +72,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor/{monitor_id}",
                 "operation_id": "delete_monitor",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -99,6 +102,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor/{monitor_id}",
                 "operation_id": "get_monitor",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -128,6 +132,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor",
                 "operation_id": "list_monitors",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -189,6 +194,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor/groups/search",
                 "operation_id": "search_monitor_groups",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -227,6 +233,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor/search",
                 "operation_id": "search_monitors",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -265,6 +272,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor/{monitor_id}",
                 "operation_id": "update_monitor",
                 "http_method": "PUT",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -284,6 +292,33 @@ class MonitorsApi:
             api_client=api_client,
         )
 
+        self._validate_existing_monitor_endpoint = _Endpoint(
+            settings={
+                "response_type": (dict,),
+                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
+                "endpoint_path": "/api/v1/monitor/{monitor_id}/validate",
+                "operation_id": "validate_existing_monitor",
+                "http_method": "POST",
+                "version": "v1",
+                "servers": None,
+            },
+            params_map={
+                "monitor_id": {
+                    "required": True,
+                    "openapi_types": (int,),
+                    "attribute": "monitor_id",
+                    "location": "path",
+                },
+                "body": {
+                    "required": True,
+                    "openapi_types": (Monitor,),
+                    "location": "body",
+                },
+            },
+            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
+            api_client=api_client,
+        )
+
         self._validate_monitor_endpoint = _Endpoint(
             settings={
                 "response_type": (dict,),
@@ -291,6 +326,7 @@ class MonitorsApi:
                 "endpoint_path": "/api/v1/monitor/validate",
                 "operation_id": "validate_monitor",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -376,6 +412,7 @@ class MonitorsApi:
         - watchdog: `event alert`
         - event-v2: `event-v2 alert`
         - audit: `audit alert`
+        - error-tracking: `error-tracking alert`
 
         #### Query Types
 
@@ -441,8 +478,6 @@ class MonitorsApi:
         - **`operator`** `<`, `<=`, `>`, `>=`, `==`, or `!=`.
         - **`#`** an integer or decimal number used to set the threshold.
 
-        **NOTE** Only available on US1-FED, US3, US5 and in closed beta on EU and US1.
-
         **Process Alert Query**
 
         Example: `processes(search).over(tags).rollup('count').last(timeframe) operator #`
@@ -509,7 +544,19 @@ class MonitorsApi:
         - **`operator`** `<`, `<=`, `>`, `>=`, `==`, or `!=`.
         - **`#`** an integer or decimal number used to set the threshold.
 
-        **NOTE** Only available in closed beta on US1, EU, US3 and US5.
+        **NOTE** CI Pipeline monitors are in alpha on US1, EU, US3 and US5.
+
+        **Error Tracking Alert Query**
+
+        Example(RUM): `error-tracking-rum(query).rollup(rollup_method[, measure]).last(time_window) operator #`
+        Example(APM Traces): `error-tracking-traces(query).rollup(rollup_method[, measure]).last(time_window) operator #`
+
+        - **`query`** The search query - following the [Log search syntax](https://docs.datadoghq.com/logs/search_syntax/).
+        - **`rollup_method`** The stats roll-up method - supports `count`, `avg`, and `cardinality`.
+        - **`measure`** For `avg` and cardinality `rollup_method` - specify the measure or the facet name you want to use.
+        - **`time_window`** #m (between 1 and 2880), #h (between 1 and 48).
+        - **`operator`** `<`, `<=`, `>`, `>=`, `==`, or `!=`.
+        - **`#`** an integer or decimal number used to set the threshold.
 
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True.
@@ -867,6 +914,54 @@ class MonitorsApi:
 
         return self._update_monitor_endpoint.call_with_http_info(**kwargs)
 
+    def validate_existing_monitor(self, monitor_id, body, **kwargs):
+        """Validate an existing monitor.
+
+        Validate the monitor provided in the request.
+
+        This method makes a synchronous HTTP request by default. To make an
+        asynchronous HTTP request, please pass async_req=True.
+
+        >>> thread = api.validate_existing_monitor(monitor_id, body, async_req=True)
+        >>> result = thread.get()
+
+        :param monitor_id: The ID of the monitor
+        :type monitor_id: int
+        :param body: Monitor request object
+        :type body: Monitor
+        :param _return_http_data_only: Response data without head status
+            code and headers. Default is True.
+        :type _return_http_data_only: bool
+        :param _preload_content: If False, the urllib3.HTTPResponse object
+            will be returned without reading/decoding response data.
+            Default is True.
+        :type _preload_content: bool
+        :param _request_timeout: Timeout setting for this request. If one
+            number provided, it will be total request timeout. It can also be a
+            pair (tuple) of (connection, read) timeouts.  Default is None.
+        :type _request_timeout: float/tuple
+        :param _check_input_type: Specifies if type checking should be done one
+            the data sent to the server. Default is True.
+        :type _check_input_type: bool
+        :param _check_return_type: Specifies if type checking should be done
+            one the data received from the server. Default is True.
+        :type _check_return_type: bool
+        :param _host_index: Specifies the index of the server that we want to
+            use. Default is read from the configuration.
+        :type _host_index: int/None
+        :param async_req: Execute request asynchronously.
+        :type async_req: bool
+
+        :return: If the method is called asynchronously, returns the request thread.
+        :rtype: dict
+        """
+        kwargs = self._validate_existing_monitor_endpoint.default_arguments(kwargs)
+        kwargs["monitor_id"] = monitor_id
+
+        kwargs["body"] = body
+
+        return self._validate_existing_monitor_endpoint.call_with_http_info(**kwargs)
+
     def validate_monitor(self, body, **kwargs):
         """Validate a monitor.
 
