@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.notebooks_response import NotebooksResponse
 from datadog_api_client.v1.model.notebook_response import NotebookResponse
 from datadog_api_client.v1.model.notebook_create_request import NotebookCreateRequest
@@ -23,6 +23,7 @@ class NotebooksApi:
                 "endpoint_path": "/api/v1/notebooks",
                 "operation_id": "create_notebook",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -43,6 +44,7 @@ class NotebooksApi:
                 "endpoint_path": "/api/v1/notebooks/{notebook_id}",
                 "operation_id": "delete_notebook",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -63,10 +65,11 @@ class NotebooksApi:
         self._get_notebook_endpoint = _Endpoint(
             settings={
                 "response_type": (NotebookResponse,),
-                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
+                "auth": ["apiKeyAuth", "appKeyAuth"],
                 "endpoint_path": "/api/v1/notebooks/{notebook_id}",
                 "operation_id": "get_notebook",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -87,10 +90,11 @@ class NotebooksApi:
         self._list_notebooks_endpoint = _Endpoint(
             settings={
                 "response_type": (NotebooksResponse,),
-                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
+                "auth": ["apiKeyAuth", "appKeyAuth"],
                 "endpoint_path": "/api/v1/notebooks",
                 "operation_id": "list_notebooks",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -159,6 +163,7 @@ class NotebooksApi:
                 "endpoint_path": "/api/v1/notebooks/{notebook_id}",
                 "operation_id": "update_notebook",
                 "http_method": "PUT",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
