@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.intake_payload_accepted import IntakePayloadAccepted
 from datadog_api_client.v1.model.service_checks import ServiceChecks
 
@@ -21,6 +21,7 @@ class ServiceChecksApi:
                 "endpoint_path": "/api/v1/check_run",
                 "operation_id": "submit_service_check",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
