@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.slo_list_response import SLOListResponse
 from datadog_api_client.v1.model.service_level_objective_request import ServiceLevelObjectiveRequest
 from datadog_api_client.v1.model.slo_bulk_delete_response import SLOBulkDeleteResponse
@@ -29,6 +29,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo/can_delete",
                 "operation_id": "check_can_delete_slo",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -53,6 +54,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo",
                 "operation_id": "create_slo",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -73,6 +75,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo/{slo_id}",
                 "operation_id": "delete_slo",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -102,6 +105,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo/bulk_delete",
                 "operation_id": "delete_slo_timeframe_in_bulk",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -122,6 +126,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo/{slo_id}",
                 "operation_id": "get_slo",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -151,6 +156,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo/{slo_id}/corrections",
                 "operation_id": "get_slo_corrections",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -175,6 +181,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo/{slo_id}/history",
                 "operation_id": "get_slo_history",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -218,13 +225,14 @@ class ServiceLevelObjectivesApi:
             api_client=api_client,
         )
 
-        self._list_sl_os_endpoint = _Endpoint(
+        self._list_slos_endpoint = _Endpoint(
             settings={
                 "response_type": (SLOListResponse,),
                 "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                 "endpoint_path": "/api/v1/slo",
-                "operation_id": "list_sl_os",
+                "operation_id": "list_slos",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -273,6 +281,7 @@ class ServiceLevelObjectivesApi:
                 "endpoint_path": "/api/v1/slo/{slo_id}",
                 "operation_id": "update_slo",
                 "http_method": "PUT",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -632,7 +641,7 @@ class ServiceLevelObjectivesApi:
 
         return self._get_slo_history_endpoint.call_with_http_info(**kwargs)
 
-    def list_sl_os(self, **kwargs):
+    def list_slos(self, **kwargs):
         """Get all SLOs.
 
         Get a list of service level objective objects for your organization.
@@ -640,7 +649,7 @@ class ServiceLevelObjectivesApi:
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True.
 
-        >>> thread = api.list_sl_os(async_req=True)
+        >>> thread = api.list_slos(async_req=True)
         >>> result = thread.get()
 
         :param ids: A comma separated list of the IDs of the service level objectives objects.
@@ -681,8 +690,8 @@ class ServiceLevelObjectivesApi:
         :return: If the method is called asynchronously, returns the request thread.
         :rtype: SLOListResponse
         """
-        kwargs = self._list_sl_os_endpoint.default_arguments(kwargs)
-        return self._list_sl_os_endpoint.call_with_http_info(**kwargs)
+        kwargs = self._list_slos_endpoint.default_arguments(kwargs)
+        return self._list_slos_endpoint.call_with_http_info(**kwargs)
 
     def update_slo(self, slo_id, body, **kwargs):
         """Update an SLO.
