@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.slack_integration_channels import SlackIntegrationChannels
 from datadog_api_client.v1.model.slack_integration_channel import SlackIntegrationChannel
 
@@ -21,6 +21,7 @@ class SlackIntegrationApi:
                 "endpoint_path": "/api/v1/integration/slack/configuration/accounts/{account_name}/channels",
                 "operation_id": "create_slack_integration_channel",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -47,6 +48,7 @@ class SlackIntegrationApi:
                 "endpoint_path": "/api/v1/integration/slack/configuration/accounts/{account_name}/channels/{channel_name}",
                 "operation_id": "get_slack_integration_channel",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -77,6 +79,7 @@ class SlackIntegrationApi:
                 "endpoint_path": "/api/v1/integration/slack/configuration/accounts/{account_name}/channels",
                 "operation_id": "get_slack_integration_channels",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -101,6 +104,7 @@ class SlackIntegrationApi:
                 "endpoint_path": "/api/v1/integration/slack/configuration/accounts/{account_name}/channels/{channel_name}",
                 "operation_id": "remove_slack_integration_channel",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -131,6 +135,7 @@ class SlackIntegrationApi:
                 "endpoint_path": "/api/v1/integration/slack/configuration/accounts/{account_name}/channels/{channel_name}",
                 "operation_id": "update_slack_integration_channel",
                 "http_method": "PATCH",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
