@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v1.model.tag_to_hosts import TagToHosts
 from datadog_api_client.v1.model.host_tags import HostTags
 
@@ -21,6 +21,7 @@ class TagsApi:
                 "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                 "operation_id": "create_host_tags",
                 "http_method": "POST",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -52,6 +53,7 @@ class TagsApi:
                 "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                 "operation_id": "delete_host_tags",
                 "http_method": "DELETE",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -81,6 +83,7 @@ class TagsApi:
                 "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                 "operation_id": "get_host_tags",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -110,6 +113,7 @@ class TagsApi:
                 "endpoint_path": "/api/v1/tags/hosts",
                 "operation_id": "list_host_tags",
                 "http_method": "GET",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
@@ -133,6 +137,7 @@ class TagsApi:
                 "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                 "operation_id": "update_host_tags",
                 "http_method": "PUT",
+                "version": "v1",
                 "servers": None,
             },
             params_map={
