@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class APIErrorResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "errors": ([str],),
         }
@@ -23,8 +20,6 @@ class APIErrorResponse(ModelNormal):
         "errors": "errors",
     }
 
-    read_only_vars = {}
-
     def __init__(self, errors, *args, **kwargs):
         """
         Error response object.
