@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,11 +16,8 @@ def lazy_import():
 
 
 class ApiKeyResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "api_key": (ApiKey,),
@@ -30,8 +27,6 @@ class ApiKeyResponse(ModelNormal):
         "api_key": "api_key",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         An API key with its associated metadata.
