@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class AWSAccountAndLambdaRequest(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "account_id": (str,),
             "lambda_arn": (str,),
@@ -25,8 +22,6 @@ class AWSAccountAndLambdaRequest(ModelNormal):
         "lambda_arn": "lambda_arn",
     }
 
-    read_only_vars = {}
-
     def __init__(self, account_id, lambda_arn, *args, **kwargs):
         """
         AWS account ID and Lambda ARN.
