@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class AWSAccountDeleteRequest(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "access_key_id": (str,),
             "account_id": (str,),
@@ -27,8 +24,6 @@ class AWSAccountDeleteRequest(ModelNormal):
         "role_name": "role_name",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         List of AWS accounts to delete.
