@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -44,11 +44,8 @@ def lazy_import():
 
 
 class ChangeWidgetRequest(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "apm_query": (LogQueryDefinition,),
@@ -92,8 +89,6 @@ class ChangeWidgetRequest(ModelNormal):
         "show_present": "show_present",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Updated change widget.
@@ -110,7 +105,7 @@ class ChangeWidgetRequest(ModelNormal):
         :param event_query: The log query.
         :type event_query: LogQueryDefinition, optional
 
-        :param formulas: List of formulas that operate on queries. **This feature is currently in beta.**
+        :param formulas: List of formulas that operate on queries.
         :type formulas: [WidgetFormula], optional
 
         :param increase_good: Whether to show increase as good.
@@ -137,10 +132,10 @@ class ChangeWidgetRequest(ModelNormal):
         :param q: Query definition.
         :type q: str, optional
 
-        :param queries: List of queries that can be returned directly or used in formulas. **This feature is currently in beta.**
+        :param queries: List of queries that can be returned directly or used in formulas.
         :type queries: [FormulaAndFunctionQueryDefinition], optional
 
-        :param response_format: Timeseries or Scalar response. **This feature is currently in beta.**
+        :param response_format: Timeseries or Scalar response.
         :type response_format: FormulaAndFunctionResponseFormat, optional
 
         :param rum_query: The log query.
