@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     none_type,
@@ -11,11 +11,8 @@ from datadog_api_client.v1.model_utils import (
 
 
 class Creator(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "email": (str,),
             "handle": (str,),
@@ -28,8 +25,6 @@ class Creator(ModelNormal):
         "name": "name",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object describing the creator of the shared element.
