@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class DashboardDeleteResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "deleted_dashboard_id": (str,),
         }
@@ -23,8 +20,6 @@ class DashboardDeleteResponse(ModelNormal):
         "deleted_dashboard_id": "deleted_dashboard_id",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Response from the delete dashboard call.
