@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class DashboardListDeleteResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "deleted_dashboard_list_id": (int,),
         }
@@ -23,8 +20,6 @@ class DashboardListDeleteResponse(ModelNormal):
         "deleted_dashboard_list_id": "deleted_dashboard_list_id",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Deleted dashboard details.
