@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -28,7 +28,6 @@ def lazy_import():
 
 
 class DistributionWidgetDefinition(ModelNormal):
-
     validations = {
         "requests": {
             "max_items": 1,
@@ -37,7 +36,7 @@ class DistributionWidgetDefinition(ModelNormal):
     }
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "legend_size": (str,),
@@ -67,8 +66,6 @@ class DistributionWidgetDefinition(ModelNormal):
         "yaxis": "yaxis",
     }
 
-    read_only_vars = {}
-
     def __init__(self, requests, type, *args, **kwargs):
         """
         The Distribution visualization is another way of showing metrics
