@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     none_type,
@@ -17,7 +17,6 @@ def lazy_import():
 
 
 class DowntimeChild(ModelNormal):
-
     validations = {
         "creator_id": {
             "inclusive_maximum": 2147483647,
@@ -32,7 +31,7 @@ class DowntimeChild(ModelNormal):
     _nullable = True
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "active": (bool,),
@@ -71,7 +70,6 @@ class DowntimeChild(ModelNormal):
         "timezone": "timezone",
         "updater_id": "updater_id",
     }
-
     read_only_vars = {
         "active",
         "canceled",
