@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class EventQueryDefinition(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "search": (str,),
             "tags_execution": (str,),
@@ -25,8 +22,6 @@ class EventQueryDefinition(ModelNormal):
         "tags_execution": "tags_execution",
     }
 
-    read_only_vars = {}
-
     def __init__(self, search, tags_execution, *args, **kwargs):
         """
         The event query.
