@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class GCPAccount(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "auth_provider_x509_cert_url": (str,),
             "auth_uri": (str,),
@@ -47,8 +44,6 @@ class GCPAccount(ModelNormal):
         "type": "type",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Your Google Cloud Platform Account.
@@ -68,8 +63,8 @@ class GCPAccount(ModelNormal):
         :param client_id: Your ID found in your JSON service account key.
         :type client_id: str, optional
 
-        :param client_x509_cert_url: Should be `https://www.googleapis.com/robot/v1/metadata/x509/<CLIENT_EMAIL>`
-            where `<CLIENT_EMAIL>` is the email found in your JSON service account key.
+        :param client_x509_cert_url: Should be `https://www.googleapis.com/robot/v1/metadata/x509/$CLIENT_EMAIL`
+            where `$CLIENT_EMAIL` is the email found in your JSON service account key.
         :type client_x509_cert_url: str, optional
 
         :param errors: An array of errors.
