@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class GeomapWidgetDefinitionView(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "focus": (str,),
         }
@@ -23,8 +20,6 @@ class GeomapWidgetDefinitionView(ModelNormal):
         "focus": "focus",
     }
 
-    read_only_vars = {}
-
     def __init__(self, focus, *args, **kwargs):
         """
         The view of the world that the map should render.
