@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -32,11 +32,8 @@ def lazy_import():
 
 
 class HeatMapWidgetRequest(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "apm_query": (LogQueryDefinition,),
@@ -64,8 +61,6 @@ class HeatMapWidgetRequest(ModelNormal):
         "style": "style",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Updated heat map widget.
