@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class HostMetaInstallMethod(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "installer_version": (str,),
             "tool": (str,),
@@ -27,8 +24,6 @@ class HostMetaInstallMethod(ModelNormal):
         "tool_version": "tool_version",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Agent install method.
