@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class HostMetrics(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "cpu": (float,),
             "iowait": (float,),
@@ -27,8 +24,6 @@ class HostMetrics(ModelNormal):
         "load": "load",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Host Metrics collected.
