@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class HostTags(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "host": (str,),
             "tags": ([str],),
@@ -25,8 +22,6 @@ class HostTags(ModelNormal):
         "tags": "tags",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Set of tags to associate with your host.
