@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class HostTotals(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "total_active": (int,),
             "total_up": (int,),
@@ -25,8 +22,6 @@ class HostTotals(ModelNormal):
         "total_up": "total_up",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Total number of host currently monitored by Datadog.
