@@ -3,14 +3,13 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class HTTPLogError(ModelNormal):
-
     validations = {
         "code": {
             "inclusive_maximum": 2147483647,
@@ -18,7 +17,7 @@ class HTTPLogError(ModelNormal):
     }
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "code": (int,),
             "message": (str,),
@@ -29,8 +28,6 @@ class HTTPLogError(ModelNormal):
         "message": "message",
     }
 
-    read_only_vars = {}
-
     def __init__(self, code, message, *args, **kwargs):
         """
         Invalid query performed.
