@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,11 +16,8 @@ def lazy_import():
 
 
 class LogsAPIError(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "code": (str,),
@@ -34,8 +31,6 @@ class LogsAPIError(ModelNormal):
         "message": "message",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Error returned by the Logs API
