@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,11 +16,8 @@ def lazy_import():
 
 
 class LogsCategoryProcessorCategory(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "filter": (LogsFilter,),
@@ -32,8 +29,6 @@ class LogsCategoryProcessorCategory(ModelNormal):
         "name": "name",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object describing the logs filter.
