@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsGrokParserRules(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "match_rules": (str,),
             "support_rules": (str,),
@@ -25,8 +22,6 @@ class LogsGrokParserRules(ModelNormal):
         "support_rules": "support_rules",
     }
 
-    read_only_vars = {}
-
     def __init__(self, match_rules, *args, **kwargs):
         """
         Set of rules for the grok parser.
