@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class MonitorOptionsAggregation(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "group_by": (str,),
             "metric": (str,),
@@ -27,8 +24,6 @@ class MonitorOptionsAggregation(ModelNormal):
         "type": "type",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Type of aggregation performed in the monitor query.
