@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ApiTypeError,
     ModelSimple,
     cached_property,
@@ -11,10 +11,8 @@ from datadog_api_client.v1.model_utils import (
 
 
 class MonitorSearchCount(ModelSimple):
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "value": ([dict],),
         }
