@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
@@ -19,11 +19,8 @@ def lazy_import():
 
 
 class MonthlyUsageAttributionBody(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "month": (datetime,),
@@ -45,8 +42,6 @@ class MonthlyUsageAttributionBody(ModelNormal):
         "values": "values",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Usage Summary by tag for a given organization.
