@@ -3,34 +3,30 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
+    none_type,
 )
 
 
 class MonthlyUsageAttributionPagination(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
-            "next_record_id": (str,),
+            "next_record_id": (str, none_type),
         }
 
     attribute_map = {
         "next_record_id": "next_record_id",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         The metadata for the current pagination.
 
         :param next_record_id: The cursor to use to get the next results, if any. To make the next request, use the same parameters with the addition of the `next_record_id`.
-        :type next_record_id: str, optional
+        :type next_record_id: str, none_type, optional
         """
         super().__init__(kwargs)
 
