@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ApiTypeError,
     ModelSimple,
     cached_property,
@@ -11,6 +11,7 @@ from datadog_api_client.v1.model_utils import (
 
 
 class MonthlyUsageAttributionSupportedMetrics(ModelSimple):
+
     allowed_values = {
         "value": {
             "API_USAGE": "api_usage",
@@ -47,10 +48,8 @@ class MonthlyUsageAttributionSupportedMetrics(ModelSimple):
         },
     }
 
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "value": (str,),
         }
