@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,12 +16,10 @@ def lazy_import():
 
 
 class NotebookRelativeTime(ModelNormal):
-
-    validations = {}
     _nullable = True
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "live_span": (WidgetLiveSpan,),
@@ -31,8 +29,6 @@ class NotebookRelativeTime(ModelNormal):
         "live_span": "live_span",
     }
 
-    read_only_vars = {}
-
     def __init__(self, live_span, *args, **kwargs):
         """
         Relative timeframe.
