@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class NotebooksResponsePage(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "total_count": (int,),
             "total_filtered_count": (int,),
@@ -25,8 +22,6 @@ class NotebooksResponsePage(ModelNormal):
         "total_filtered_count": "total_filtered_count",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Pagination metadata returned by the API.
