@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -28,11 +28,8 @@ def lazy_import():
 
 
 class OrganizationSettings(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "private_widget_share": (bool,),
@@ -60,8 +57,6 @@ class OrganizationSettings(ModelNormal):
         "saml_strict_mode": "saml_strict_mode",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A JSON array of settings.
