@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class OrganizationSettingsSamlAutocreateUsersDomains(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "domains": ([str],),
             "enabled": (bool,),
@@ -25,8 +22,6 @@ class OrganizationSettingsSamlAutocreateUsersDomains(ModelNormal):
         "enabled": "enabled",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Has two properties, `enabled` (boolean) and `domains`, which is a list of domains without the @ symbol.
