@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class PagerDutyServiceName(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "service_name": (str,),
         }
@@ -23,8 +20,6 @@ class PagerDutyServiceName(ModelNormal):
         "service_name": "service_name",
     }
 
-    read_only_vars = {}
-
     def __init__(self, service_name, *args, **kwargs):
         """
         PagerDuty service object name.
