@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -42,11 +42,8 @@ def lazy_import():
 
 
 class QueryValueWidgetRequest(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "aggregator": (WidgetAggregator,),
@@ -84,8 +81,6 @@ class QueryValueWidgetRequest(ModelNormal):
         "security_query": "security_query",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Updated query value widget.
@@ -105,7 +100,7 @@ class QueryValueWidgetRequest(ModelNormal):
         :param event_query: The log query.
         :type event_query: LogQueryDefinition, optional
 
-        :param formulas: List of formulas that operate on queries. **This feature is currently in beta.**
+        :param formulas: List of formulas that operate on queries.
         :type formulas: [WidgetFormula], optional
 
         :param log_query: The log query.
@@ -123,10 +118,10 @@ class QueryValueWidgetRequest(ModelNormal):
         :param q: TODO.
         :type q: str, optional
 
-        :param queries: List of queries that can be returned directly or used in formulas. **This feature is currently in beta.**
+        :param queries: List of queries that can be returned directly or used in formulas.
         :type queries: [FormulaAndFunctionQueryDefinition], optional
 
-        :param response_format: Timeseries or Scalar response. **This feature is currently in beta.**
+        :param response_format: Timeseries or Scalar response.
         :type response_format: FormulaAndFunctionResponseFormat, optional
 
         :param rum_query: The log query.
