@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,23 +16,11 @@ def lazy_import():
 
 
 class SLOBulkDelete(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def additional_properties_type():
+    def additional_properties_type(_):
         lazy_import()
         return ([SLOTimeframe],)
 
-    @cached_property
-    def openapi_types():
-        lazy_import()
-        return {}
-
-    attribute_map = {}
-
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A map of service level objective object IDs to arrays of timeframes,
