@@ -3,28 +3,17 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SLOErrorBudgetRemainingData(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def additional_properties_type():
+    def additional_properties_type(_):
         return (float,)
 
-    @cached_property
-    def openapi_types():
-        return {}
-
-    attribute_map = {}
-
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A mapping of threshold `timeframe` to the remaining error budget.
