@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -24,11 +24,8 @@ def lazy_import():
 
 
 class SyntheticsAPIStep(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "allow_failure": (bool,),
@@ -52,8 +49,6 @@ class SyntheticsAPIStep(ModelNormal):
         "subtype": "subtype",
     }
 
-    read_only_vars = {}
-
     def __init__(self, name, request, subtype, *args, **kwargs):
         """
         The steps used in a Synthetics multistep API test.
