@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -22,11 +22,8 @@ def lazy_import():
 
 
 class SyntheticsAPITestResultData(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "cert": (SyntheticsSSLCertificate,),
@@ -52,8 +49,6 @@ class SyntheticsAPITestResultData(ModelNormal):
         "timings": "timings",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object containing results for your Synthetic API test.
