@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SyntheticsCoreWebVitals(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "cls": (int,),
             "lcp": (int,),
@@ -27,8 +24,6 @@ class SyntheticsCoreWebVitals(ModelNormal):
         "url": "url",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Core Web Vitals attached to a browser test step.
