@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SyntheticsDeleteTestsPayload(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "public_ids": ([str],),
         }
@@ -23,8 +20,6 @@ class SyntheticsDeleteTestsPayload(ModelNormal):
         "public_ids": "public_ids",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A JSON list of the ID or IDs of the Synthetic tests that you want
