@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
@@ -11,11 +11,8 @@ from datadog_api_client.v1.model_utils import (
 
 
 class SyntheticsDeletedTest(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "deleted_at": (datetime,),
             "public_id": (str,),
@@ -26,8 +23,6 @@ class SyntheticsDeletedTest(ModelNormal):
         "public_id": "public_id",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object containing a deleted Synthetic test ID with the associated
