@@ -3,34 +3,36 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
+def lazy_import():
+    from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles
+
+    globals()["SyntheticsRestrictedRoles"] = SyntheticsRestrictedRoles
+
+
 class SyntheticsGlobalVariableAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
+        lazy_import()
         return {
-            "restricted_roles": ([str],),
+            "restricted_roles": (SyntheticsRestrictedRoles,),
         }
 
     attribute_map = {
         "restricted_roles": "restricted_roles",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Attributes of the global variable.
 
-        :param restricted_roles: List of role identifiers that can be pulled from the Roles API.
-        :type restricted_roles: [str], optional
+        :param restricted_roles: A list of role identifiers that can be pulled from the Roles API, for restricting read and write access.
+        :type restricted_roles: SyntheticsRestrictedRoles, optional
         """
         super().__init__(kwargs)
 
