@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SyntheticsLocation(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "id": (str,),
             "name": (str,),
@@ -25,8 +22,6 @@ class SyntheticsLocation(ModelNormal):
         "name": "name",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Synthetic location that can be used when creating or editing a
