@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -20,11 +20,8 @@ def lazy_import():
 
 
 class SyntheticsParsingOptions(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "field": (str,),
@@ -40,8 +37,6 @@ class SyntheticsParsingOptions(ModelNormal):
         "type": "type",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Parsing options for variables to extract.
