@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SyntheticsPrivateLocationSecretsAuthentication(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "id": (str,),
             "key": (str,),
@@ -24,7 +21,6 @@ class SyntheticsPrivateLocationSecretsAuthentication(ModelNormal):
         "id": "id",
         "key": "key",
     }
-
     read_only_vars = {
         "id",
         "key",
