@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class TagToHosts(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "tags": ({str: ([str],)},),
         }
@@ -23,8 +20,6 @@ class TagToHosts(ModelNormal):
         "tags": "tags",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         In this object, the key is the tag, the value is a list of host names that are reporting that tag.
