@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class UsageAttributionAggregatesBody(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "agg_type": (str,),
             "field": (str,),
@@ -27,8 +24,6 @@ class UsageAttributionAggregatesBody(ModelNormal):
         "value": "value",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         The object containing the aggregates.
