@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
@@ -11,11 +11,8 @@ from datadog_api_client.v1.model_utils import (
 
 
 class UsageHostHour(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "agent_host_count": (int,),
             "alibaba_host_count": (int,),
@@ -54,8 +51,6 @@ class UsageHostHour(ModelNormal):
         "vsphere_host_count": "vsphere_host_count",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Number of hosts/containers recorded for each hour for a given organization.
