@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
@@ -17,11 +17,8 @@ def lazy_import():
 
 
 class UsageSummaryDate(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "agent_host_top99p": (int,),
@@ -37,6 +34,10 @@ class UsageSummaryDate(ModelNormal):
             "browser_rum_lite_session_count_sum": (int,),
             "browser_rum_replay_session_count_sum": (int,),
             "browser_rum_units_sum": (int,),
+            "ci_pipeline_indexed_spans_sum": (int,),
+            "ci_test_indexed_spans_sum": (int,),
+            "ci_visibility_pipeline_committers_hwm": (int,),
+            "ci_visibility_test_committers_hwm": (int,),
             "container_avg": (int,),
             "container_hwm": (int,),
             "cspm_aas_host_top99p": (int,),
@@ -67,6 +68,8 @@ class UsageSummaryDate(ModelNormal):
             "mobile_rum_units_sum": (int,),
             "netflow_indexed_events_count_sum": (int,),
             "npm_host_top99p": (int,),
+            "observability_pipelines_bytes_processed_sum": (int,),
+            "online_archive_events_count_sum": (int,),
             "opentelemetry_host_top99p": (int,),
             "orgs": ([UsageSummaryDateOrg],),
             "profiling_host_top99p": (int,),
@@ -97,6 +100,10 @@ class UsageSummaryDate(ModelNormal):
         "browser_rum_lite_session_count_sum": "browser_rum_lite_session_count_sum",
         "browser_rum_replay_session_count_sum": "browser_rum_replay_session_count_sum",
         "browser_rum_units_sum": "browser_rum_units_sum",
+        "ci_pipeline_indexed_spans_sum": "ci_pipeline_indexed_spans_sum",
+        "ci_test_indexed_spans_sum": "ci_test_indexed_spans_sum",
+        "ci_visibility_pipeline_committers_hwm": "ci_visibility_pipeline_committers_hwm",
+        "ci_visibility_test_committers_hwm": "ci_visibility_test_committers_hwm",
         "container_avg": "container_avg",
         "container_hwm": "container_hwm",
         "cspm_aas_host_top99p": "cspm_aas_host_top99p",
@@ -127,6 +134,8 @@ class UsageSummaryDate(ModelNormal):
         "mobile_rum_units_sum": "mobile_rum_units_sum",
         "netflow_indexed_events_count_sum": "netflow_indexed_events_count_sum",
         "npm_host_top99p": "npm_host_top99p",
+        "observability_pipelines_bytes_processed_sum": "observability_pipelines_bytes_processed_sum",
+        "online_archive_events_count_sum": "online_archive_events_count_sum",
         "opentelemetry_host_top99p": "opentelemetry_host_top99p",
         "orgs": "orgs",
         "profiling_host_top99p": "profiling_host_top99p",
@@ -143,8 +152,6 @@ class UsageSummaryDate(ModelNormal):
         "vsphere_host_top99p": "vsphere_host_top99p",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Response with hourly report of all data billed by Datadog all organizations.
@@ -188,6 +195,18 @@ class UsageSummaryDate(ModelNormal):
         :param browser_rum_units_sum: Shows the sum of all browser RUM units over all hours in the current date for all organizations.
         :type browser_rum_units_sum: int, optional
 
+        :param ci_pipeline_indexed_spans_sum: Shows the sum of all CI pipeline indexed spans over all hours in the current month for all organizations.
+        :type ci_pipeline_indexed_spans_sum: int, optional
+
+        :param ci_test_indexed_spans_sum: Shows the sum of all CI test indexed spans over all hours in the current month for all organizations.
+        :type ci_test_indexed_spans_sum: int, optional
+
+        :param ci_visibility_pipeline_committers_hwm: Shows the high-water mark of all CI visibility pipeline committers over all hours in the current month for all organizations.
+        :type ci_visibility_pipeline_committers_hwm: int, optional
+
+        :param ci_visibility_test_committers_hwm: Shows the high-water mark of all CI visibility test committers over all hours in the current month for all organizations.
+        :type ci_visibility_test_committers_hwm: int, optional
+
         :param container_avg: Shows the average of all distinct containers over all hours in the current date for all organizations.
         :type container_avg: int, optional
 
@@ -278,6 +297,12 @@ class UsageSummaryDate(ModelNormal):
         :param npm_host_top99p: Shows the 99th percentile of all distinct Networks hosts over all hours in the current date for all organizations.
         :type npm_host_top99p: int, optional
 
+        :param observability_pipelines_bytes_processed_sum: Sum of all observability pipelines bytes processed over all hours in the current date for the given org.
+        :type observability_pipelines_bytes_processed_sum: int, optional
+
+        :param online_archive_events_count_sum: Sum of all online archived events over all hours in the current date for all organizations.
+        :type online_archive_events_count_sum: int, optional
+
         :param opentelemetry_host_top99p: Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for all organizations.
         :type opentelemetry_host_top99p: int, optional
 
@@ -314,7 +339,7 @@ class UsageSummaryDate(ModelNormal):
         :param trace_search_indexed_events_count_sum: Shows the sum of all Indexed Spans indexed over all hours in the current date for all organizations.
         :type trace_search_indexed_events_count_sum: int, optional
 
-        :param twol_ingested_events_bytes_sum: Shows the sum of all tracing without limits bytes ingested over all hours in the current date for all organizations.
+        :param twol_ingested_events_bytes_sum: Shows the sum of all ingested APM span bytes over all hours in the current date for all organizations.
         :type twol_ingested_events_bytes_sum: int, optional
 
         :param vsphere_host_top99p: Shows the 99th percentile of all vSphere hosts over all hours in the current date for all organizations.
