@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class UsageSummaryDateOrg(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "agent_host_top99p": (int,),
             "apm_azure_app_service_host_top99p": (int,),
@@ -29,6 +26,10 @@ class UsageSummaryDateOrg(ModelNormal):
             "browser_rum_lite_session_count_sum": (int,),
             "browser_rum_replay_session_count_sum": (int,),
             "browser_rum_units_sum": (int,),
+            "ci_pipeline_indexed_spans_sum": (int,),
+            "ci_test_indexed_spans_sum": (int,),
+            "ci_visibility_pipeline_committers_hwm": (int,),
+            "ci_visibility_test_committers_hwm": (int,),
             "container_avg": (int,),
             "container_hwm": (int,),
             "cspm_aas_host_top99p": (int,),
@@ -60,6 +61,8 @@ class UsageSummaryDateOrg(ModelNormal):
             "name": (str,),
             "netflow_indexed_events_count_sum": (int,),
             "npm_host_top99p": (int,),
+            "observability_pipelines_bytes_processed_sum": (int,),
+            "online_archive_events_count_sum": (int,),
             "opentelemetry_host_top99p": (int,),
             "profiling_host_top99p": (int,),
             "public_id": (str,),
@@ -90,6 +93,10 @@ class UsageSummaryDateOrg(ModelNormal):
         "browser_rum_lite_session_count_sum": "browser_rum_lite_session_count_sum",
         "browser_rum_replay_session_count_sum": "browser_rum_replay_session_count_sum",
         "browser_rum_units_sum": "browser_rum_units_sum",
+        "ci_pipeline_indexed_spans_sum": "ci_pipeline_indexed_spans_sum",
+        "ci_test_indexed_spans_sum": "ci_test_indexed_spans_sum",
+        "ci_visibility_pipeline_committers_hwm": "ci_visibility_pipeline_committers_hwm",
+        "ci_visibility_test_committers_hwm": "ci_visibility_test_committers_hwm",
         "container_avg": "container_avg",
         "container_hwm": "container_hwm",
         "cspm_aas_host_top99p": "cspm_aas_host_top99p",
@@ -121,6 +128,8 @@ class UsageSummaryDateOrg(ModelNormal):
         "name": "name",
         "netflow_indexed_events_count_sum": "netflow_indexed_events_count_sum",
         "npm_host_top99p": "npm_host_top99p",
+        "observability_pipelines_bytes_processed_sum": "observability_pipelines_bytes_processed_sum",
+        "online_archive_events_count_sum": "online_archive_events_count_sum",
         "opentelemetry_host_top99p": "opentelemetry_host_top99p",
         "profiling_host_top99p": "profiling_host_top99p",
         "public_id": "public_id",
@@ -137,8 +146,6 @@ class UsageSummaryDateOrg(ModelNormal):
         "vsphere_host_top99p": "vsphere_host_top99p",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Global hourly report of all data billed by Datadog for a given organization.
@@ -182,6 +189,18 @@ class UsageSummaryDateOrg(ModelNormal):
         :param browser_rum_units_sum: Shows the sum of all browser RUM units over all hours in the current date for the given org.
         :type browser_rum_units_sum: int, optional
 
+        :param ci_pipeline_indexed_spans_sum: Shows the sum of all CI pipeline indexed spans over all hours in the current date for the given org.
+        :type ci_pipeline_indexed_spans_sum: int, optional
+
+        :param ci_test_indexed_spans_sum: Shows the sum of all CI test indexed spans over all hours in the current date for the given org.
+        :type ci_test_indexed_spans_sum: int, optional
+
+        :param ci_visibility_pipeline_committers_hwm: Shows the high-water mark of all CI visibility pipeline committers over all hours in the current date for the given org.
+        :type ci_visibility_pipeline_committers_hwm: int, optional
+
+        :param ci_visibility_test_committers_hwm: Shows the high-water mark of all CI visibility test committers over all hours in the current date for the given org.
+        :type ci_visibility_test_committers_hwm: int, optional
+
         :param container_avg: Shows the average of all distinct containers over all hours in the current date for the given org.
         :type container_avg: int, optional
 
@@ -275,6 +294,12 @@ class UsageSummaryDateOrg(ModelNormal):
         :param npm_host_top99p: Shows the 99th percentile of all distinct Networks hosts over all hours in the current date for the given org.
         :type npm_host_top99p: int, optional
 
+        :param observability_pipelines_bytes_processed_sum: Sum of all observability pipelines bytes processed over all hours in the current date for the given org.
+        :type observability_pipelines_bytes_processed_sum: int, optional
+
+        :param online_archive_events_count_sum: Sum of all online archived events over all hours in the current date for the given org.
+        :type online_archive_events_count_sum: int, optional
+
         :param opentelemetry_host_top99p: Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for the given org.
         :type opentelemetry_host_top99p: int, optional
 
@@ -311,7 +336,7 @@ class UsageSummaryDateOrg(ModelNormal):
         :param trace_search_indexed_events_count_sum: Shows the sum of all Indexed Spans indexed over all hours in the current date for the given org.
         :type trace_search_indexed_events_count_sum: int, optional
 
-        :param twol_ingested_events_bytes_sum: Shows the sum of all tracing without limits bytes ingested over all hours in the current date for the given org.
+        :param twol_ingested_events_bytes_sum: Shows the sum of all ingested APM span bytes over all hours in the current date for the given org.
         :type twol_ingested_events_bytes_sum: int, optional
 
         :param vsphere_host_top99p: Shows the 99th percentile of all vSphere hosts over all hours in the current date for the given org.
