@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
@@ -19,11 +19,8 @@ def lazy_import():
 
 
 class UsageSummaryResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "agent_host_top99p_sum": (int,),
@@ -40,6 +37,10 @@ class UsageSummaryResponse(ModelNormal):
             "browser_rum_lite_session_count_agg_sum": (int,),
             "browser_rum_replay_session_count_agg_sum": (int,),
             "browser_rum_units_agg_sum": (int,),
+            "ci_pipeline_indexed_spans_agg_sum": (int,),
+            "ci_test_indexed_spans_agg_sum": (int,),
+            "ci_visibility_pipeline_committers_hwm_sum": (int,),
+            "ci_visibility_test_committers_hwm_sum": (int,),
             "container_avg_sum": (int,),
             "container_hwm_sum": (int,),
             "cspm_aas_host_top99p_sum": (int,),
@@ -74,6 +75,8 @@ class UsageSummaryResponse(ModelNormal):
             "mobile_rum_units_agg_sum": (int,),
             "netflow_indexed_events_count_agg_sum": (int,),
             "npm_host_top99p_sum": (int,),
+            "observability_pipelines_bytes_processed_agg_sum": (int,),
+            "online_archive_events_count_agg_sum": (int,),
             "opentelemetry_host_top99p_sum": (int,),
             "profiling_container_agent_count_avg": (int,),
             "profiling_host_count_top99p_sum": (int,),
@@ -109,6 +112,10 @@ class UsageSummaryResponse(ModelNormal):
         "browser_rum_lite_session_count_agg_sum": "browser_rum_lite_session_count_agg_sum",
         "browser_rum_replay_session_count_agg_sum": "browser_rum_replay_session_count_agg_sum",
         "browser_rum_units_agg_sum": "browser_rum_units_agg_sum",
+        "ci_pipeline_indexed_spans_agg_sum": "ci_pipeline_indexed_spans_agg_sum",
+        "ci_test_indexed_spans_agg_sum": "ci_test_indexed_spans_agg_sum",
+        "ci_visibility_pipeline_committers_hwm_sum": "ci_visibility_pipeline_committers_hwm_sum",
+        "ci_visibility_test_committers_hwm_sum": "ci_visibility_test_committers_hwm_sum",
         "container_avg_sum": "container_avg_sum",
         "container_hwm_sum": "container_hwm_sum",
         "cspm_aas_host_top99p_sum": "cspm_aas_host_top99p_sum",
@@ -143,6 +150,8 @@ class UsageSummaryResponse(ModelNormal):
         "mobile_rum_units_agg_sum": "mobile_rum_units_agg_sum",
         "netflow_indexed_events_count_agg_sum": "netflow_indexed_events_count_agg_sum",
         "npm_host_top99p_sum": "npm_host_top99p_sum",
+        "observability_pipelines_bytes_processed_agg_sum": "observability_pipelines_bytes_processed_agg_sum",
+        "online_archive_events_count_agg_sum": "online_archive_events_count_agg_sum",
         "opentelemetry_host_top99p_sum": "opentelemetry_host_top99p_sum",
         "profiling_container_agent_count_avg": "profiling_container_agent_count_avg",
         "profiling_host_count_top99p_sum": "profiling_host_count_top99p_sum",
@@ -163,8 +172,6 @@ class UsageSummaryResponse(ModelNormal):
         "vsphere_host_top99p_sum": "vsphere_host_top99p_sum",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Response summarizing all usage aggregated across the months in the request for all organizations, and broken down by month and by organization.
@@ -211,6 +218,18 @@ class UsageSummaryResponse(ModelNormal):
         :param browser_rum_units_agg_sum: Shows the sum of all browser RUM units over all hours in the current months for all organizations.
         :type browser_rum_units_agg_sum: int, optional
 
+        :param ci_pipeline_indexed_spans_agg_sum: Shows the sum of all CI pipeline indexed spans over all hours in the current months for all organizations.
+        :type ci_pipeline_indexed_spans_agg_sum: int, optional
+
+        :param ci_test_indexed_spans_agg_sum: Shows the sum of all CI test indexed spans over all hours in the current months for all organizations.
+        :type ci_test_indexed_spans_agg_sum: int, optional
+
+        :param ci_visibility_pipeline_committers_hwm_sum: Shows the high-water mark of all CI visibility pipeline committers over all hours in the current months for all organizations.
+        :type ci_visibility_pipeline_committers_hwm_sum: int, optional
+
+        :param ci_visibility_test_committers_hwm_sum: Shows the high-water mark of all CI visibility test committers over all hours in the current months for all organizations.
+        :type ci_visibility_test_committers_hwm_sum: int, optional
+
         :param container_avg_sum: Shows the average of all distinct containers over all hours in the current months for all organizations.
         :type container_avg_sum: int, optional
 
@@ -313,6 +332,12 @@ class UsageSummaryResponse(ModelNormal):
         :param npm_host_top99p_sum: Shows the 99th percentile of all distinct Networks hosts over all hours in the current months for all organizations.
         :type npm_host_top99p_sum: int, optional
 
+        :param observability_pipelines_bytes_processed_agg_sum: Sum of all observability pipelines bytes processed over all hours in the current months for all organizations.
+        :type observability_pipelines_bytes_processed_agg_sum: int, optional
+
+        :param online_archive_events_count_agg_sum: Sum of all online archived events over all hours in the current months for all organizations.
+        :type online_archive_events_count_agg_sum: int, optional
+
         :param opentelemetry_host_top99p_sum: Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current months for all organizations.
         :type opentelemetry_host_top99p_sum: int, optional
 
@@ -358,7 +383,7 @@ class UsageSummaryResponse(ModelNormal):
         :param trace_search_indexed_events_count_agg_sum: Shows the sum of all Indexed Spans indexed over all hours in the current months for all organizations.
         :type trace_search_indexed_events_count_agg_sum: int, optional
 
-        :param twol_ingested_events_bytes_agg_sum: Shows the sum of all tracing without limits bytes ingested over all hours in the current months for all organizations.
+        :param twol_ingested_events_bytes_agg_sum: Shows the sum of all ingested APM span bytes over all hours in the current months for all organizations.
         :type twol_ingested_events_bytes_agg_sum: int, optional
 
         :param usage: An array of objects regarding hourly usage.
