@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -18,11 +18,8 @@ def lazy_import():
 
 
 class Widget(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "definition": (WidgetDefinition,),
@@ -36,8 +33,6 @@ class Widget(ModelNormal):
         "layout": "layout",
     }
 
-    read_only_vars = {}
-
     def __init__(self, definition, *args, **kwargs):
         """
         Information about widget.
