@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelComposed,
     cached_property,
 )
@@ -72,13 +72,6 @@ def lazy_import():
 
 
 class WidgetDefinition(ModelComposed):
-
-    validations = {}
-
-    @cached_property
-    def openapi_types():
-        return {}
-
     def __init__(self, *args, **kwargs):
         """
         [Definition of the widget](https://docs.datadoghq.com/dashboards/widgets/).
@@ -298,6 +291,9 @@ class WidgetDefinition(ModelComposed):
         :param custom_unit: Display a unit of your choice on the widget.
         :type custom_unit: str, optional
 
+        :param timeseries_background: Set a timeseries on the widget background.
+        :type timeseries_background: TimeseriesBackground, optional
+
         :param color_by_groups: List of groups used for colors.
         :type color_by_groups: [str], optional
 
@@ -391,7 +387,7 @@ class WidgetDefinition(ModelComposed):
         return self
 
     @cached_property
-    def _composed_schemas():
+    def _composed_schemas(_):
         # we need this here to make our import statements work
         # we must store _composed_schemas in here so the code is only run
         # when we invoke this method. If we kept this at the class
