@@ -563,6 +563,7 @@ from datadog_api_client.v1.model.synthetics_private_location_creation_response i
 from datadog_api_client.v1.model.synthetics_private_location_creation_response_result_encryption import (
     SyntheticsPrivateLocationCreationResponseResultEncryption,
 )
+from datadog_api_client.v1.model.synthetics_private_location_metadata import SyntheticsPrivateLocationMetadata
 from datadog_api_client.v1.model.synthetics_private_location_secrets import SyntheticsPrivateLocationSecrets
 from datadog_api_client.v1.model.synthetics_private_location_secrets_authentication import (
     SyntheticsPrivateLocationSecretsAuthentication,
@@ -570,6 +571,7 @@ from datadog_api_client.v1.model.synthetics_private_location_secrets_authenticat
 from datadog_api_client.v1.model.synthetics_private_location_secrets_config_decryption import (
     SyntheticsPrivateLocationSecretsConfigDecryption,
 )
+from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles
 from datadog_api_client.v1.model.synthetics_ssl_certificate import SyntheticsSSLCertificate
 from datadog_api_client.v1.model.synthetics_ssl_certificate_issuer import SyntheticsSSLCertificateIssuer
 from datadog_api_client.v1.model.synthetics_ssl_certificate_subject import SyntheticsSSLCertificateSubject
@@ -612,6 +614,8 @@ from datadog_api_client.v1.model.table_widget_has_search_bar import TableWidgetH
 from datadog_api_client.v1.model.table_widget_request import TableWidgetRequest
 from datadog_api_client.v1.model.tag_to_hosts import TagToHosts
 from datadog_api_client.v1.model.target_format_type import TargetFormatType
+from datadog_api_client.v1.model.timeseries_background import TimeseriesBackground
+from datadog_api_client.v1.model.timeseries_background_type import TimeseriesBackgroundType
 from datadog_api_client.v1.model.timeseries_widget_definition import TimeseriesWidgetDefinition
 from datadog_api_client.v1.model.timeseries_widget_definition_type import TimeseriesWidgetDefinitionType
 from datadog_api_client.v1.model.timeseries_widget_expression_alias import TimeseriesWidgetExpressionAlias
@@ -645,6 +649,8 @@ from datadog_api_client.v1.model.usage_billable_summary_body import UsageBillabl
 from datadog_api_client.v1.model.usage_billable_summary_hour import UsageBillableSummaryHour
 from datadog_api_client.v1.model.usage_billable_summary_keys import UsageBillableSummaryKeys
 from datadog_api_client.v1.model.usage_billable_summary_response import UsageBillableSummaryResponse
+from datadog_api_client.v1.model.usage_ci_visibility_hour import UsageCIVisibilityHour
+from datadog_api_client.v1.model.usage_ci_visibility_response import UsageCIVisibilityResponse
 from datadog_api_client.v1.model.usage_cws_hour import UsageCWSHour
 from datadog_api_client.v1.model.usage_cws_response import UsageCWSResponse
 from datadog_api_client.v1.model.usage_cloud_security_posture_management_hour import (
@@ -670,8 +676,8 @@ from datadog_api_client.v1.model.usage_indexed_spans_hour import UsageIndexedSpa
 from datadog_api_client.v1.model.usage_indexed_spans_response import UsageIndexedSpansResponse
 from datadog_api_client.v1.model.usage_ingested_spans_hour import UsageIngestedSpansHour
 from datadog_api_client.v1.model.usage_ingested_spans_response import UsageIngestedSpansResponse
-from datadog_api_client.v1.model.usage_io_t_hour import UsageIoTHour
-from datadog_api_client.v1.model.usage_io_t_response import UsageIoTResponse
+from datadog_api_client.v1.model.usage_iot_hour import UsageIoTHour
+from datadog_api_client.v1.model.usage_iot_response import UsageIoTResponse
 from datadog_api_client.v1.model.usage_lambda_hour import UsageLambdaHour
 from datadog_api_client.v1.model.usage_lambda_response import UsageLambdaResponse
 from datadog_api_client.v1.model.usage_logs_by_index_hour import UsageLogsByIndexHour
@@ -685,6 +691,8 @@ from datadog_api_client.v1.model.usage_network_flows_hour import UsageNetworkFlo
 from datadog_api_client.v1.model.usage_network_flows_response import UsageNetworkFlowsResponse
 from datadog_api_client.v1.model.usage_network_hosts_hour import UsageNetworkHostsHour
 from datadog_api_client.v1.model.usage_network_hosts_response import UsageNetworkHostsResponse
+from datadog_api_client.v1.model.usage_online_archive_hour import UsageOnlineArchiveHour
+from datadog_api_client.v1.model.usage_online_archive_response import UsageOnlineArchiveResponse
 from datadog_api_client.v1.model.usage_profiling_hour import UsageProfilingHour
 from datadog_api_client.v1.model.usage_profiling_response import UsageProfilingResponse
 from datadog_api_client.v1.model.usage_reports_type import UsageReportsType
@@ -716,6 +724,7 @@ from datadog_api_client.v1.model.usage_timeseries_hour import UsageTimeseriesHou
 from datadog_api_client.v1.model.usage_timeseries_response import UsageTimeseriesResponse
 from datadog_api_client.v1.model.usage_top_avg_metrics_hour import UsageTopAvgMetricsHour
 from datadog_api_client.v1.model.usage_top_avg_metrics_metadata import UsageTopAvgMetricsMetadata
+from datadog_api_client.v1.model.usage_top_avg_metrics_pagination import UsageTopAvgMetricsPagination
 from datadog_api_client.v1.model.usage_top_avg_metrics_response import UsageTopAvgMetricsResponse
 from datadog_api_client.v1.model.user import User
 from datadog_api_client.v1.model.user_disable_response import UserDisableResponse
