@@ -3,7 +3,11 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.model_utils import (
+    set_attribute_from_path,
+    get_attribute_from_path,
+)
 from datadog_api_client.v2.model.incidents_response import IncidentsResponse
 from datadog_api_client.v2.model.incident_related_object import IncidentRelatedObject
 from datadog_api_client.v2.model.incident_response import IncidentResponse
@@ -24,6 +28,7 @@ class IncidentsApi:
                 "endpoint_path": "/api/v2/incidents",
                 "operation_id": "create_incident",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -44,6 +49,7 @@ class IncidentsApi:
                 "endpoint_path": "/api/v2/incidents/{incident_id}",
                 "operation_id": "delete_incident",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -68,6 +74,7 @@ class IncidentsApi:
                 "endpoint_path": "/api/v2/incidents/{incident_id}",
                 "operation_id": "get_incident",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -98,6 +105,7 @@ class IncidentsApi:
                 "endpoint_path": "/api/v2/incidents",
                 "operation_id": "list_incidents",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -132,6 +140,7 @@ class IncidentsApi:
                 "endpoint_path": "/api/v2/incidents/{incident_id}",
                 "operation_id": "update_incident",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -337,6 +346,51 @@ class IncidentsApi:
         kwargs = self._list_incidents_endpoint.default_arguments(kwargs)
         return self._list_incidents_endpoint.call_with_http_info(**kwargs)
 
+    def list_incidents_with_pagination(self, **kwargs):
+        """Get a list of incidents.
+
+        Provide a paginated version of :meth:`list_incidents`, returning all items.
+
+        :param include: Specifies which types of related objects should be included in the response.
+        :type include: [IncidentRelatedObject], optional
+        :param page_size: Size for a given page.
+        :type page_size: int, optional
+        :param page_offset: Specific offset to use as the beginning of the returned page.
+        :type page_offset: int, optional
+        :param _request_timeout: Timeout setting for this request. If one
+            number provided, it will be total request timeout. It can also be a
+            pair (tuple) of (connection, read) timeouts.  Default is None.
+        :type _request_timeout: float/tuple
+        :param _check_input_type: Specifies if type checking should be done one
+            the data sent to the server. Default is True.
+        :type _check_input_type: bool
+        :param _check_return_type: Specifies if type checking should be done
+            one the data received from the server. Default is True.
+        :type _check_return_type: bool
+        :param _host_index: Specifies the index of the server that we want to
+            use. Default is read from the configuration.
+        :type _host_index: int/None
+
+        :return: A generator of paginated results.
+        :rtype: collections.abc.Iterable[IncidentResponseData]
+        """
+        kwargs = self._list_incidents_endpoint.default_arguments(kwargs)
+        page_size = get_attribute_from_path(kwargs, "page_size", 10)
+        endpoint = self._list_incidents_endpoint
+        set_attribute_from_path(kwargs, "page_size", page_size, endpoint.params_map)
+        while True:
+            response = endpoint.call_with_http_info(**kwargs)
+            for item in get_attribute_from_path(response, "data"):
+                yield item
+            if len(get_attribute_from_path(response, "data")) < page_size:
+                break
+            set_attribute_from_path(
+                kwargs,
+                "page_offset",
+                get_attribute_from_path(kwargs, "page_offset", 0) + page_size,
+                endpoint.params_map,
+            )
+
     def update_incident(self, incident_id, body, **kwargs):
         """Update an existing incident.
 
