@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v2.model.api_keys_response import APIKeysResponse
 from datadog_api_client.v2.model.api_keys_sort import APIKeysSort
 from datadog_api_client.v2.model.api_key_response import APIKeyResponse
@@ -29,6 +29,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/api_keys",
                 "operation_id": "create_api_key",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -49,6 +50,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/current_user/application_keys",
                 "operation_id": "create_current_user_application_key",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -69,6 +71,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/api_keys/{api_key_id}",
                 "operation_id": "delete_api_key",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -93,6 +96,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/application_keys/{app_key_id}",
                 "operation_id": "delete_application_key",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -117,6 +121,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/current_user/application_keys/{app_key_id}",
                 "operation_id": "delete_current_user_application_key",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -141,6 +146,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/api_keys/{api_key_id}",
                 "operation_id": "get_api_key",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -170,6 +176,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/application_keys/{app_key_id}",
                 "operation_id": "get_application_key",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -199,6 +206,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/current_user/application_keys/{app_key_id}",
                 "operation_id": "get_current_user_application_key",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -223,6 +231,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/api_keys",
                 "operation_id": "list_api_keys",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -286,6 +295,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/application_keys",
                 "operation_id": "list_application_keys",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -334,6 +344,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/current_user/application_keys",
                 "operation_id": "list_current_user_application_keys",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -382,6 +393,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/api_keys/{api_key_id}",
                 "operation_id": "update_api_key",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -408,6 +420,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/application_keys/{app_key_id}",
                 "operation_id": "update_application_key",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -434,6 +447,7 @@ class KeyManagementApi:
                 "endpoint_path": "/api/v2/current_user/application_keys/{app_key_id}",
                 "operation_id": "update_current_user_application_key",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -464,7 +478,6 @@ class KeyManagementApi:
         >>> thread = api.create_api_key(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: APIKeyCreateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -508,7 +521,6 @@ class KeyManagementApi:
         >>> thread = api.create_current_user_application_key(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: ApplicationKeyCreateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -990,7 +1002,6 @@ class KeyManagementApi:
 
         :param api_key_id: The ID of the API key.
         :type api_key_id: str
-
         :type body: APIKeyUpdateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -1038,7 +1049,6 @@ class KeyManagementApi:
 
         :param app_key_id: The ID of the application key.
         :type app_key_id: str
-
         :type body: ApplicationKeyUpdateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -1086,7 +1096,6 @@ class KeyManagementApi:
 
         :param app_key_id: The ID of the application key.
         :type app_key_id: str
-
         :type body: ApplicationKeyUpdateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
