@@ -3,9 +3,11 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.api_client import ApiClient, Endpoint as _Endpoint
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.model_utils import (
     datetime,
+    set_attribute_from_path,
+    get_attribute_from_path,
 )
 from datadog_api_client.v2.model.content_encoding import ContentEncoding
 from datadog_api_client.v2.model.http_log import HTTPLog
@@ -29,6 +31,7 @@ class LogsApi:
                 "endpoint_path": "/api/v2/logs/analytics/aggregate",
                 "operation_id": "aggregate_logs",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -49,6 +52,7 @@ class LogsApi:
                 "endpoint_path": "/api/v2/logs/events/search",
                 "operation_id": "list_logs",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -68,6 +72,7 @@ class LogsApi:
                 "endpoint_path": "/api/v2/logs/events",
                 "operation_id": "list_logs_get",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -124,6 +129,7 @@ class LogsApi:
                 "endpoint_path": "/api/v2/logs",
                 "operation_id": "submit_log",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": [
                     {
                         "url": "https://{subdomain}.{site}",
@@ -209,7 +215,6 @@ class LogsApi:
         >>> thread = api.aggregate_logs(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: LogsAggregateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -263,7 +268,6 @@ class LogsApi:
         >>> thread = api.list_logs(async_req=True)
         >>> result = thread.get()
 
-
         :type body: LogsListRequest, optional
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -294,6 +298,43 @@ class LogsApi:
         kwargs = self._list_logs_endpoint.default_arguments(kwargs)
         return self._list_logs_endpoint.call_with_http_info(**kwargs)
 
+    def list_logs_with_pagination(self, **kwargs):
+        """Search logs.
+
+        Provide a paginated version of :meth:`list_logs`, returning all items.
+
+        :type body: LogsListRequest, optional
+        :param _request_timeout: Timeout setting for this request. If one
+            number provided, it will be total request timeout. It can also be a
+            pair (tuple) of (connection, read) timeouts.  Default is None.
+        :type _request_timeout: float/tuple
+        :param _check_input_type: Specifies if type checking should be done one
+            the data sent to the server. Default is True.
+        :type _check_input_type: bool
+        :param _check_return_type: Specifies if type checking should be done
+            one the data received from the server. Default is True.
+        :type _check_return_type: bool
+        :param _host_index: Specifies the index of the server that we want to
+            use. Default is read from the configuration.
+        :type _host_index: int/None
+
+        :return: A generator of paginated results.
+        :rtype: collections.abc.Iterable[Log]
+        """
+        kwargs = self._list_logs_endpoint.default_arguments(kwargs)
+        page_size = get_attribute_from_path(kwargs, "body.page.limit", 10)
+        endpoint = self._list_logs_endpoint
+        set_attribute_from_path(kwargs, "body.page.limit", page_size, endpoint.params_map)
+        while True:
+            response = endpoint.call_with_http_info(**kwargs)
+            for item in get_attribute_from_path(response, "data"):
+                yield item
+            if len(get_attribute_from_path(response, "data")) < page_size:
+                break
+            set_attribute_from_path(
+                kwargs, "body.page.cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
+            )
+
     def list_logs_get(self, **kwargs):
         """Get a list of logs.
 
@@ -359,6 +400,57 @@ class LogsApi:
         kwargs = self._list_logs_get_endpoint.default_arguments(kwargs)
         return self._list_logs_get_endpoint.call_with_http_info(**kwargs)
 
+    def list_logs_get_with_pagination(self, **kwargs):
+        """Get a list of logs.
+
+        Provide a paginated version of :meth:`list_logs_get`, returning all items.
+
+        :param filter_query: Search query following logs syntax.
+        :type filter_query: str, optional
+        :param filter_index: For customers with multiple indexes, the indexes to search
+            Defaults to '*' which means all indexes
+        :type filter_index: str, optional
+        :param filter_from: Minimum timestamp for requested logs.
+        :type filter_from: datetime, optional
+        :param filter_to: Maximum timestamp for requested logs.
+        :type filter_to: datetime, optional
+        :param sort: Order of logs in results.
+        :type sort: LogsSort, optional
+        :param page_cursor: List following results with a cursor provided in the previous query.
+        :type page_cursor: str, optional
+        :param page_limit: Maximum number of logs in the response.
+        :type page_limit: int, optional
+        :param _request_timeout: Timeout setting for this request. If one
+            number provided, it will be total request timeout. It can also be a
+            pair (tuple) of (connection, read) timeouts.  Default is None.
+        :type _request_timeout: float/tuple
+        :param _check_input_type: Specifies if type checking should be done one
+            the data sent to the server. Default is True.
+        :type _check_input_type: bool
+        :param _check_return_type: Specifies if type checking should be done
+            one the data received from the server. Default is True.
+        :type _check_return_type: bool
+        :param _host_index: Specifies the index of the server that we want to
+            use. Default is read from the configuration.
+        :type _host_index: int/None
+
+        :return: A generator of paginated results.
+        :rtype: collections.abc.Iterable[Log]
+        """
+        kwargs = self._list_logs_get_endpoint.default_arguments(kwargs)
+        page_size = get_attribute_from_path(kwargs, "page_limit", 10)
+        endpoint = self._list_logs_get_endpoint
+        set_attribute_from_path(kwargs, "page_limit", page_size, endpoint.params_map)
+        while True:
+            response = endpoint.call_with_http_info(**kwargs)
+            for item in get_attribute_from_path(response, "data"):
+                yield item
+            if len(get_attribute_from_path(response, "data")) < page_size:
+                break
+            set_attribute_from_path(
+                kwargs, "page_cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
+            )
+
     def submit_log(self, body, **kwargs):
         """Send logs.
 
