@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v2.model.permissions_response import PermissionsResponse
 from datadog_api_client.v2.model.roles_response import RolesResponse
 from datadog_api_client.v2.model.roles_sort import RolesSort
@@ -31,6 +31,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}/permissions",
                 "operation_id": "add_permission_to_role",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -57,6 +58,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}/users",
                 "operation_id": "add_user_to_role",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -83,6 +85,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}/clone",
                 "operation_id": "clone_role",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -109,6 +112,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles",
                 "operation_id": "create_role",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -129,6 +133,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}",
                 "operation_id": "delete_role",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -153,6 +158,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}",
                 "operation_id": "get_role",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -177,6 +183,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/permissions",
                 "operation_id": "list_permissions",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={},
@@ -194,6 +201,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}/permissions",
                 "operation_id": "list_role_permissions",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -218,6 +226,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles",
                 "operation_id": "list_roles",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -256,6 +265,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}/users",
                 "operation_id": "list_role_users",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -300,6 +310,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}/permissions",
                 "operation_id": "remove_permission_from_role",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -326,6 +337,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}/users",
                 "operation_id": "remove_user_from_role",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -352,6 +364,7 @@ class RolesApi:
                 "endpoint_path": "/api/v2/roles/{role_id}",
                 "operation_id": "update_role",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -382,9 +395,8 @@ class RolesApi:
         >>> thread = api.add_permission_to_role(role_id, body, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
-
         :type body: RelationshipToPermission
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -430,9 +442,8 @@ class RolesApi:
         >>> thread = api.add_user_to_role(role_id, body, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
-
         :type body: RelationshipToUser
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -478,9 +489,8 @@ class RolesApi:
         >>> thread = api.clone_role(role_id, body, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
-
         :type body: RoleCloneRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -526,7 +536,6 @@ class RolesApi:
         >>> thread = api.create_role(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: RoleCreateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -570,7 +579,7 @@ class RolesApi:
         >>> thread = api.delete_role(role_id, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -614,7 +623,7 @@ class RolesApi:
         >>> thread = api.get_role(role_id, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -698,7 +707,7 @@ class RolesApi:
         >>> thread = api.list_role_permissions(role_id, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -734,7 +743,7 @@ class RolesApi:
     def list_roles(self, **kwargs):
         """List roles.
 
-        Returns all roles, including their names and IDs.
+        Returns all roles, including their names and their unique identifiers.
 
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True.
@@ -792,7 +801,7 @@ class RolesApi:
         >>> thread = api.list_role_users(role_id, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
         :param page_size: Size for a given page.
         :type page_size: int, optional
@@ -846,9 +855,8 @@ class RolesApi:
         >>> thread = api.remove_permission_from_role(role_id, body, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
-
         :type body: RelationshipToPermission
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -894,9 +902,8 @@ class RolesApi:
         >>> thread = api.remove_user_from_role(role_id, body, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
-
         :type body: RelationshipToUser
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -942,9 +949,8 @@ class RolesApi:
         >>> thread = api.update_role(role_id, body, async_req=True)
         >>> result = thread.get()
 
-        :param role_id: The ID of the role.
+        :param role_id: The unique identifier of the role.
         :type role_id: str
-
         :type body: RoleUpdateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
