@@ -3,9 +3,11 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.api_client import ApiClient, Endpoint as _Endpoint
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.model_utils import (
     datetime,
+    set_attribute_from_path,
+    get_attribute_from_path,
 )
 from datadog_api_client.v2.model.security_filters_response import SecurityFiltersResponse
 from datadog_api_client.v2.model.security_filter_response import SecurityFilterResponse
@@ -33,6 +35,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/configuration/security_filters",
                 "operation_id": "create_security_filter",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -53,6 +56,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/rules",
                 "operation_id": "create_security_monitoring_rule",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -73,6 +77,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/configuration/security_filters/{security_filter_id}",
                 "operation_id": "delete_security_filter",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -97,6 +102,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/rules/{rule_id}",
                 "operation_id": "delete_security_monitoring_rule",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -121,6 +127,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/configuration/security_filters/{security_filter_id}",
                 "operation_id": "get_security_filter",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -145,6 +152,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/rules/{rule_id}",
                 "operation_id": "get_security_monitoring_rule",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -169,6 +177,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/configuration/security_filters",
                 "operation_id": "list_security_filters",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={},
@@ -186,6 +195,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/rules",
                 "operation_id": "list_security_monitoring_rules",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -214,6 +224,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/signals",
                 "operation_id": "list_security_monitoring_signals",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -265,6 +276,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/signals/search",
                 "operation_id": "search_security_monitoring_signals",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -284,6 +296,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/configuration/security_filters/{security_filter_id}",
                 "operation_id": "update_security_filter",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -310,6 +323,7 @@ class SecurityMonitoringApi:
                 "endpoint_path": "/api/v2/security_monitoring/rules/{rule_id}",
                 "operation_id": "update_security_monitoring_rule",
                 "http_method": "PUT",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -387,7 +401,6 @@ class SecurityMonitoringApi:
         >>> thread = api.create_security_monitoring_rule(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: SecurityMonitoringRuleCreatePayload
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -737,6 +750,54 @@ class SecurityMonitoringApi:
         kwargs = self._list_security_monitoring_signals_endpoint.default_arguments(kwargs)
         return self._list_security_monitoring_signals_endpoint.call_with_http_info(**kwargs)
 
+    def list_security_monitoring_signals_with_pagination(self, **kwargs):
+        """Get a quick list of security signals.
+
+        Provide a paginated version of :meth:`list_security_monitoring_signals`, returning all items.
+
+        :param filter_query: The search query for security signals.
+        :type filter_query: str, optional
+        :param filter_from: The minimum timestamp for requested security signals.
+        :type filter_from: datetime, optional
+        :param filter_to: The maximum timestamp for requested security signals.
+        :type filter_to: datetime, optional
+        :param sort: The order of the security signals in results.
+        :type sort: SecurityMonitoringSignalsSort, optional
+        :param page_cursor: A list of results using the cursor provided in the previous query.
+        :type page_cursor: str, optional
+        :param page_limit: The maximum number of security signals in the response.
+        :type page_limit: int, optional
+        :param _request_timeout: Timeout setting for this request. If one
+            number provided, it will be total request timeout. It can also be a
+            pair (tuple) of (connection, read) timeouts.  Default is None.
+        :type _request_timeout: float/tuple
+        :param _check_input_type: Specifies if type checking should be done one
+            the data sent to the server. Default is True.
+        :type _check_input_type: bool
+        :param _check_return_type: Specifies if type checking should be done
+            one the data received from the server. Default is True.
+        :type _check_return_type: bool
+        :param _host_index: Specifies the index of the server that we want to
+            use. Default is read from the configuration.
+        :type _host_index: int/None
+
+        :return: A generator of paginated results.
+        :rtype: collections.abc.Iterable[SecurityMonitoringSignal]
+        """
+        kwargs = self._list_security_monitoring_signals_endpoint.default_arguments(kwargs)
+        page_size = get_attribute_from_path(kwargs, "page_limit", 10)
+        endpoint = self._list_security_monitoring_signals_endpoint
+        set_attribute_from_path(kwargs, "page_limit", page_size, endpoint.params_map)
+        while True:
+            response = endpoint.call_with_http_info(**kwargs)
+            for item in get_attribute_from_path(response, "data"):
+                yield item
+            if len(get_attribute_from_path(response, "data")) < page_size:
+                break
+            set_attribute_from_path(
+                kwargs, "page_cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
+            )
+
     def search_security_monitoring_signals(self, **kwargs):
         """Get a list of security signals.
 
@@ -750,7 +811,6 @@ class SecurityMonitoringApi:
         >>> thread = api.search_security_monitoring_signals(async_req=True)
         >>> result = thread.get()
 
-
         :type body: SecurityMonitoringSignalListRequest, optional
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -781,6 +841,43 @@ class SecurityMonitoringApi:
         kwargs = self._search_security_monitoring_signals_endpoint.default_arguments(kwargs)
         return self._search_security_monitoring_signals_endpoint.call_with_http_info(**kwargs)
 
+    def search_security_monitoring_signals_with_pagination(self, **kwargs):
+        """Get a list of security signals.
+
+        Provide a paginated version of :meth:`search_security_monitoring_signals`, returning all items.
+
+        :type body: SecurityMonitoringSignalListRequest, optional
+        :param _request_timeout: Timeout setting for this request. If one
+            number provided, it will be total request timeout. It can also be a
+            pair (tuple) of (connection, read) timeouts.  Default is None.
+        :type _request_timeout: float/tuple
+        :param _check_input_type: Specifies if type checking should be done one
+            the data sent to the server. Default is True.
+        :type _check_input_type: bool
+        :param _check_return_type: Specifies if type checking should be done
+            one the data received from the server. Default is True.
+        :type _check_return_type: bool
+        :param _host_index: Specifies the index of the server that we want to
+            use. Default is read from the configuration.
+        :type _host_index: int/None
+
+        :return: A generator of paginated results.
+        :rtype: collections.abc.Iterable[SecurityMonitoringSignal]
+        """
+        kwargs = self._search_security_monitoring_signals_endpoint.default_arguments(kwargs)
+        page_size = get_attribute_from_path(kwargs, "body.page.limit", 10)
+        endpoint = self._search_security_monitoring_signals_endpoint
+        set_attribute_from_path(kwargs, "body.page.limit", page_size, endpoint.params_map)
+        while True:
+            response = endpoint.call_with_http_info(**kwargs)
+            for item in get_attribute_from_path(response, "data"):
+                yield item
+            if len(get_attribute_from_path(response, "data")) < page_size:
+                break
+            set_attribute_from_path(
+                kwargs, "body.page.cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
+            )
+
     def update_security_filter(self, security_filter_id, body, **kwargs):
         """Update a security filter.
 
@@ -845,7 +942,6 @@ class SecurityMonitoringApi:
 
         :param rule_id: The ID of the rule.
         :type rule_id: str
-
         :type body: SecurityMonitoringRuleUpdatePayload
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
