@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v2.model.list_application_keys_response import ListApplicationKeysResponse
 from datadog_api_client.v2.model.application_keys_sort import ApplicationKeysSort
 from datadog_api_client.v2.model.application_key_response import ApplicationKeyResponse
@@ -25,6 +25,7 @@ class ServiceAccountsApi:
                 "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys",
                 "operation_id": "create_service_account_application_key",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -51,6 +52,7 @@ class ServiceAccountsApi:
                 "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}",
                 "operation_id": "delete_service_account_application_key",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -81,6 +83,7 @@ class ServiceAccountsApi:
                 "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}",
                 "operation_id": "get_service_account_application_key",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -111,6 +114,7 @@ class ServiceAccountsApi:
                 "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys",
                 "operation_id": "list_service_account_application_keys",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -165,6 +169,7 @@ class ServiceAccountsApi:
                 "endpoint_path": "/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}",
                 "operation_id": "update_service_account_application_key",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -203,7 +208,6 @@ class ServiceAccountsApi:
 
         :param service_account_id: The ID of the service account.
         :type service_account_id: str
-
         :type body: ApplicationKeyCreateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -407,7 +411,6 @@ class ServiceAccountsApi:
         :type service_account_id: str
         :param app_key_id: The ID of the application key.
         :type app_key_id: str
-
         :type body: ApplicationKeyUpdateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
