@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.api_client import ApiClient, Endpoint as _Endpoint
+from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
 from datadog_api_client.v2.model.user_response import UserResponse
 from datadog_api_client.v2.model.service_account_create_request import ServiceAccountCreateRequest
 from datadog_api_client.v2.model.user_invitations_response import UserInvitationsResponse
@@ -29,6 +29,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/service_accounts",
                 "operation_id": "create_service_account",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -49,6 +50,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/users",
                 "operation_id": "create_user",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -69,6 +71,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/users/{user_id}",
                 "operation_id": "disable_user",
                 "http_method": "DELETE",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -93,6 +96,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/user_invitations/{user_invitation_uuid}",
                 "operation_id": "get_invitation",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -117,6 +121,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/users/{user_id}",
                 "operation_id": "get_user",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -141,6 +146,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/users/{user_id}/orgs",
                 "operation_id": "list_user_organizations",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -165,6 +171,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/users/{user_id}/permissions",
                 "operation_id": "list_user_permissions",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -189,6 +196,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/users",
                 "operation_id": "list_users",
                 "http_method": "GET",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -237,6 +245,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/user_invitations",
                 "operation_id": "send_invitations",
                 "http_method": "POST",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -257,6 +266,7 @@ class UsersApi:
                 "endpoint_path": "/api/v2/users/{user_id}",
                 "operation_id": "update_user",
                 "http_method": "PATCH",
+                "version": "v2",
                 "servers": None,
             },
             params_map={
@@ -287,7 +297,6 @@ class UsersApi:
         >>> thread = api.create_service_account(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: ServiceAccountCreateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -331,7 +340,6 @@ class UsersApi:
         >>> thread = api.create_user(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: UserCreateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -656,7 +664,6 @@ class UsersApi:
         >>> thread = api.send_invitations(body, async_req=True)
         >>> result = thread.get()
 
-
         :type body: UserInvitationsRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
@@ -703,7 +710,6 @@ class UsersApi:
 
         :param user_id: The ID of the user.
         :type user_id: str
-
         :type body: UserUpdateRequest
         :param _return_http_data_only: Response data without head status
             code and headers. Default is True.
