@@ -1,4 +1,5 @@
-from datadog_api_client.v2.api.auth_n_mappings_api import AuthNMappingsApi
+from datadog_api_client.v2.api.audit_api import AuditApi
+from datadog_api_client.v2.api.authn_mappings_api import AuthNMappingsApi
 from datadog_api_client.v2.api.cloud_workload_security_api import CloudWorkloadSecurityApi
 from datadog_api_client.v2.api.dashboard_lists_api import DashboardListsApi
 from datadog_api_client.v2.api.incident_services_api import IncidentServicesApi
@@ -9,8 +10,11 @@ from datadog_api_client.v2.api.logs_api import LogsApi
 from datadog_api_client.v2.api.logs_archives_api import LogsArchivesApi
 from datadog_api_client.v2.api.logs_metrics_api import LogsMetricsApi
 from datadog_api_client.v2.api.metrics_api import MetricsApi
+from datadog_api_client.v2.api.organizations_api import OrganizationsApi
 from datadog_api_client.v2.api.processes_api import ProcessesApi
+from datadog_api_client.v2.api.rum_api import RUMApi
 from datadog_api_client.v2.api.roles_api import RolesApi
 from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
 from datadog_api_client.v2.api.service_accounts_api import ServiceAccountsApi
+from datadog_api_client.v2.api.usage_metering_api import UsageMeteringApi
 from datadog_api_client.v2.api.users_api import UsersApi
