@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     none_type,
@@ -11,11 +11,8 @@ from datadog_api_client.v2.model_utils import (
 
 
 class ApplicationKeyUpdateAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "name": (str,),
             "scopes": ([str], none_type),
@@ -26,8 +23,6 @@ class ApplicationKeyUpdateAttributes(ModelNormal):
         "scopes": "scopes",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Attributes used to update an application Key.
