@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -22,11 +22,8 @@ def lazy_import():
 
 
 class CloudWorkloadSecurityAgentRuleAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "category": (str,),
@@ -56,8 +53,6 @@ class CloudWorkloadSecurityAgentRuleAttributes(ModelNormal):
         "version": "version",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A Cloud Workload Security Agent rule returned by the API.
