@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class CloudWorkloadSecurityAgentRuleCreatorAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "handle": (str,),
             "name": (str,),
@@ -25,8 +22,6 @@ class CloudWorkloadSecurityAgentRuleCreatorAttributes(ModelNormal):
         "name": "name",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         The attributes of the user who created the Agent rule.
