@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,11 +16,8 @@ def lazy_import():
 
 
 class DashboardListItemResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "id": (str,),
@@ -31,7 +28,6 @@ class DashboardListItemResponse(ModelNormal):
         "id": "id",
         "type": "type",
     }
-
     read_only_vars = {
         "id",
     }
