@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -20,11 +20,8 @@ def lazy_import():
 
 
 class IncidentUpdateData(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "attributes": (IncidentUpdateAttributes,),
@@ -40,8 +37,6 @@ class IncidentUpdateData(ModelNormal):
         "type": "type",
     }
 
-    read_only_vars = {}
-
     def __init__(self, id, type, *args, **kwargs):
         """
         Incident data for an update request.
