@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsArchiveIntegrationGCS(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "client_email": (str,),
             "project_id": (str,),
@@ -25,8 +22,6 @@ class LogsArchiveIntegrationGCS(ModelNormal):
         "project_id": "project_id",
     }
 
-    read_only_vars = {}
-
     def __init__(self, client_email, project_id, *args, **kwargs):
         """
         The GCS archive's integration destination.
