@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsArchiveIntegrationS3(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "account_id": (str,),
             "role_name": (str,),
@@ -25,8 +22,6 @@ class LogsArchiveIntegrationS3(ModelNormal):
         "role_name": "role_name",
     }
 
-    read_only_vars = {}
-
     def __init__(self, account_id, role_name, *args, **kwargs):
         """
         The S3 Archive's integration destination.
