@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsArchiveOrderAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "archive_ids": ([str],),
         }
@@ -23,8 +20,6 @@ class LogsArchiveOrderAttributes(ModelNormal):
         "archive_ids": "archive_ids",
     }
 
-    read_only_vars = {}
-
     def __init__(self, archive_ids, *args, **kwargs):
         """
         The attributes associated with the archive order.
