@@ -3,20 +3,13 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelComposed,
     cached_property,
 )
 
 
 class LogsGroupByMissing(ModelComposed):
-
-    validations = {}
-
-    @cached_property
-    def openapi_types():
-        return {}
-
     def __init__(self, *args, **kwargs):
         """
         The value to use for logs that don't have the facet used to group by
@@ -36,7 +29,7 @@ class LogsGroupByMissing(ModelComposed):
         return self
 
     @cached_property
-    def _composed_schemas():
+    def _composed_schemas(_):
         # we need this here to make our import statements work
         # we must store _composed_schemas in here so the code is only run
         # when we invoke this method. If we kept this at the class
