@@ -3,14 +3,13 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsListRequestPage(ModelNormal):
-
     validations = {
         "limit": {
             "inclusive_maximum": 1000,
@@ -18,7 +17,7 @@ class LogsListRequestPage(ModelNormal):
     }
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "cursor": (str,),
             "limit": (int,),
@@ -29,8 +28,6 @@ class LogsListRequestPage(ModelNormal):
         "limit": "limit",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Paging attributes for listing logs.
