@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsWarning(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "code": (str,),
             "detail": (str,),
@@ -27,8 +24,6 @@ class LogsWarning(ModelNormal):
         "title": "title",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A warning message indicating something that went wrong with the query
