@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class MetricIngestedIndexedVolumeAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "indexed_volume": (int,),
             "ingested_volume": (int,),
@@ -25,8 +22,6 @@ class MetricIngestedIndexedVolumeAttributes(ModelNormal):
         "ingested_volume": "ingested_volume",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object containing the definition of a metric's ingested and indexed volume.
