@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,12 +16,10 @@ def lazy_import():
 
 
 class NullableRelationshipToUserData(ModelNormal):
-
-    validations = {}
     _nullable = True
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "id": (str,),
@@ -33,8 +31,6 @@ class NullableRelationshipToUserData(ModelNormal):
         "type": "type",
     }
 
-    read_only_vars = {}
-
     def __init__(self, id, type, *args, **kwargs):
         """
         Relationship to user object.
