@@ -3,14 +3,13 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class ProcessSummariesMetaPage(ModelNormal):
-
     validations = {
         "size": {
             "inclusive_maximum": 10000,
@@ -19,7 +18,7 @@ class ProcessSummariesMetaPage(ModelNormal):
     }
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "after": (str,),
             "size": (int,),
@@ -30,8 +29,6 @@ class ProcessSummariesMetaPage(ModelNormal):
         "size": "size",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Paging attributes.
