@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -18,11 +18,8 @@ def lazy_import():
 
 
 class RelationshipToIncidentPostmortem(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "data": (RelationshipToIncidentPostmortemData,),
@@ -32,8 +29,6 @@ class RelationshipToIncidentPostmortem(ModelNormal):
         "data": "data",
     }
 
-    read_only_vars = {}
-
     def __init__(self, data, *args, **kwargs):
         """
         A relationship reference for postmortems.
