@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,11 +16,8 @@ def lazy_import():
 
 
 class RelationshipToRoleData(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "id": (str,),
@@ -32,13 +29,11 @@ class RelationshipToRoleData(ModelNormal):
         "type": "type",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Relationship to role object.
 
-        :param id: ID of the role.
+        :param id: The unique identifier of the role.
         :type id: str, optional
 
         :param type: Roles type.
