@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,11 +16,8 @@ def lazy_import():
 
 
 class RelationshipToRoles(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "data": ([RelationshipToRoleData],),
@@ -30,13 +27,11 @@ class RelationshipToRoles(ModelNormal):
         "data": "data",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Relationship to roles.
 
-        :param data: An array containing type and ID of a role.
+        :param data: An array containing type and the unique identifier of a role.
         :type data: [RelationshipToRoleData], optional
         """
         super().__init__(kwargs)
