@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -18,11 +18,8 @@ def lazy_import():
 
 
 class RoleUpdateData(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "attributes": (RoleUpdateAttributes,),
@@ -36,8 +33,6 @@ class RoleUpdateData(ModelNormal):
         "type": "type",
     }
 
-    read_only_vars = {}
-
     def __init__(self, attributes, id, type, *args, **kwargs):
         """
         Data related to the update of a role.
@@ -45,7 +40,7 @@ class RoleUpdateData(ModelNormal):
         :param attributes: Attributes of the role.
         :type attributes: RoleUpdateAttributes
 
-        :param id: ID of the role.
+        :param id: The unique identifier of the role.
         :type id: str
 
         :param type: Roles type.
