@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SAMLAssertionAttributeAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "attribute_key": (str,),
             "attribute_value": (str,),
@@ -25,8 +22,6 @@ class SAMLAssertionAttributeAttributes(ModelNormal):
         "attribute_value": "attribute_value",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Key/Value pair of attributes used in SAML assertion attributes.
