@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SecurityFilterExclusionFilterResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "name": (str,),
             "query": (str,),
@@ -25,8 +22,6 @@ class SecurityFilterExclusionFilterResponse(ModelNormal):
         "query": "query",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A single exclusion filter.
