@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -16,6 +16,9 @@ def lazy_import():
     from datadog_api_client.v2.model.security_monitoring_rule_evaluation_window import (
         SecurityMonitoringRuleEvaluationWindow,
     )
+    from datadog_api_client.v2.model.security_monitoring_rule_impossible_travel_options import (
+        SecurityMonitoringRuleImpossibleTravelOptions,
+    )
     from datadog_api_client.v2.model.security_monitoring_rule_keep_alive import SecurityMonitoringRuleKeepAlive
     from datadog_api_client.v2.model.security_monitoring_rule_max_signal_duration import (
         SecurityMonitoringRuleMaxSignalDuration,
@@ -26,21 +29,20 @@ def lazy_import():
 
     globals()["SecurityMonitoringRuleDetectionMethod"] = SecurityMonitoringRuleDetectionMethod
     globals()["SecurityMonitoringRuleEvaluationWindow"] = SecurityMonitoringRuleEvaluationWindow
+    globals()["SecurityMonitoringRuleImpossibleTravelOptions"] = SecurityMonitoringRuleImpossibleTravelOptions
     globals()["SecurityMonitoringRuleKeepAlive"] = SecurityMonitoringRuleKeepAlive
     globals()["SecurityMonitoringRuleMaxSignalDuration"] = SecurityMonitoringRuleMaxSignalDuration
     globals()["SecurityMonitoringRuleNewValueOptions"] = SecurityMonitoringRuleNewValueOptions
 
 
 class SecurityMonitoringRuleOptions(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "detection_method": (SecurityMonitoringRuleDetectionMethod,),
             "evaluation_window": (SecurityMonitoringRuleEvaluationWindow,),
+            "impossible_travel_options": (SecurityMonitoringRuleImpossibleTravelOptions,),
             "keep_alive": (SecurityMonitoringRuleKeepAlive,),
             "max_signal_duration": (SecurityMonitoringRuleMaxSignalDuration,),
             "new_value_options": (SecurityMonitoringRuleNewValueOptions,),
@@ -49,13 +51,12 @@ class SecurityMonitoringRuleOptions(ModelNormal):
     attribute_map = {
         "detection_method": "detectionMethod",
         "evaluation_window": "evaluationWindow",
+        "impossible_travel_options": "impossibleTravelOptions",
         "keep_alive": "keepAlive",
         "max_signal_duration": "maxSignalDuration",
         "new_value_options": "newValueOptions",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Options on rules.
@@ -67,6 +68,9 @@ class SecurityMonitoringRuleOptions(ModelNormal):
             and evaluates in real time.
         :type evaluation_window: SecurityMonitoringRuleEvaluationWindow, optional
 
+        :param impossible_travel_options: Options on impossible travel rules.
+        :type impossible_travel_options: SecurityMonitoringRuleImpossibleTravelOptions, optional
+
         :param keep_alive: Once a signal is generated, the signal will remain “open” if a case is matched at least once within
             this keep alive window.
         :type keep_alive: SecurityMonitoringRuleKeepAlive, optional
