@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
@@ -24,11 +24,8 @@ def lazy_import():
 
 
 class SecurityMonitoringRuleResponse(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         lazy_import()
         return {
             "cases": ([SecurityMonitoringRuleCase],),
@@ -70,8 +67,6 @@ class SecurityMonitoringRuleResponse(ModelNormal):
         "version": "version",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Rule.
