@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
@@ -11,11 +11,8 @@ from datadog_api_client.v2.model_utils import (
 
 
 class SecurityMonitoringSignalListRequestFilter(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "_from": (datetime,),
             "query": (str,),
@@ -28,8 +25,6 @@ class SecurityMonitoringSignalListRequestFilter(ModelNormal):
         "to": "to",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Search filters for listing security signals.
