@@ -15,9 +15,9 @@ try:
         from ddtrace.internal.writer import AgentWriter
 
         writer = AgentWriter(
-            tracer.writer.agent_url,
+            tracer._writer.agent_url,
             sync_mode=True,
-            priority_sampler=tracer.priority_sampler,
+            priority_sampler=tracer._priority_sampler,
         )
         tracer.configure(writer)
 
@@ -61,8 +61,15 @@ from dateutil.relativedelta import relativedelta
 from jinja2 import Template, Environment, meta
 from pytest_bdd import given, parsers, then, when
 
+from datadog_api_client import exceptions
+from datadog_api_client.api_client import ApiClient
+from datadog_api_client.configuration import Configuration
+
 logging.basicConfig()
 
+with (pathlib.Path(__file__).parent.parent / ".generator" / "src" / "generator" / "replacement.json").open() as f:
+    EDGE_CASES = json.load(f)
+
 PATTERN_ALPHANUM = re.compile(r"[^A-Za-z0-9]+")
 PATTERN_DOUBLE_UNDERSCORE = re.compile(r"__+")
 PATTERN_LEADING_ALPHA = re.compile(r"(.)([A-Z][a-z]+)")
@@ -108,17 +115,6 @@ def pytest_bdd_before_scenario(request, feature, scenario):
             if codeowners:
                 span.set_tag("test.codeowners", json.dumps(codeowners))
 
-    skip_tags = {"skip", "skip-python"}
-    if RECORD != "none":
-        # ignore integration-only scenarios if the recording is enabled
-        skip_tags.add("integration-only")
-    if RECORD != "false":
-        skip_tags.add("replay-only")
-
-    skipped_tags = [tag for tag in scenario.tags | scenario.feature.tags if tag in skip_tags]
-    if skipped_tags:
-        pytest.skip(f"skipped because of following tag(s): {', '.join(skipped_tags)}")
-
 
 def pytest_bdd_after_scenario(request, feature, scenario):
     try:
@@ -157,11 +153,23 @@ def pytest_bdd_step_error(request, feature, scenario, step, step_func, step_func
 
 
 def pytest_bdd_apply_tag(tag, function):
-    """Do not register tags as custom markers."""
-    return True
+    """Register tags as custom markers and skip test for '@skip' ones."""
+    skip_tags = {"skip", "skip-python"}
+    if RECORD != "none":
+        # ignore integration-only scenarios if the recording is enabled
+        skip_tags.add("integration-only")
+    if RECORD != "false":
+        skip_tags.add("replay-only")
+
+    if tag in skip_tags:
+        marker = pytest.mark.skip(reason=f"skipped because of '{tag} in {skip_tags}")
+        marker(function)
+        return True
 
 
 def snake_case(value):
+    for token, replacement in EDGE_CASES.items():
+        value = value.replace(token, replacement)
     s1 = PATTERN_LEADING_ALPHA.sub(r"\1_\2", value)
     s1 = PATTERN_FOLLOWING_ALPHA.sub(r"\1_\2", s1).lower()
     s1 = PATTERN_WHITESPACE.sub("_", s1)
@@ -190,48 +198,46 @@ def _get_prefix(request):
 
 
 @pytest.fixture
-def unique(request, freezer):
+def unique(request, freezed_time):
     prefix = _get_prefix(request)
-    with freezer:
-        return f"{prefix}-{int(datetime.utcnow().timestamp())}"
+    return f"{prefix}-{int(freezed_time.timestamp())}"
 
 
-def relative_time(freezer, iso):
+def relative_time(freezed_time, iso):
     time_re = re.compile(r"now( *([+-]) *(\d+)([smhdMy]))?")
 
     def func(arg):
-        with freezer:
-            ret = datetime.now()
-            m = time_re.match(arg)
-            if m:
-                if m.group(1):
-                    sign = m.group(2)
-                    num = int(sign + m.group(3))
-                    unit = m.group(4)
-                    if unit == "s":
-                        ret += relativedelta(seconds=num)
-                    elif unit == "m":
-                        ret += relativedelta(minutes=num)
-                    elif unit == "h":
-                        ret += relativedelta(hours=num)
-                    elif unit == "d":
-                        ret += relativedelta(days=num)
-                    elif unit == "M":
-                        ret += relativedelta(months=num)
-                    elif unit == "y":
-                        ret += relativedelta(years=num)
-                if iso:
-                    return ret  # return datetime object and not string
-                    # NOTE this is not a full ISO 8601 format, but it's enough for our needs
-                    # return ret.strftime('%Y-%m-%dT%H:%M:%S') + ret.strftime('.%f')[:4] + 'Z'
-                return int(ret.timestamp())
-            return ""
+        ret = freezed_time
+        m = time_re.match(arg)
+        if m:
+            if m.group(1):
+                sign = m.group(2)
+                num = int(sign + m.group(3))
+                unit = m.group(4)
+                if unit == "s":
+                    ret += relativedelta(seconds=num)
+                elif unit == "m":
+                    ret += relativedelta(minutes=num)
+                elif unit == "h":
+                    ret += relativedelta(hours=num)
+                elif unit == "d":
+                    ret += relativedelta(days=num)
+                elif unit == "M":
+                    ret += relativedelta(months=num)
+                elif unit == "y":
+                    ret += relativedelta(years=num)
+            if iso:
+                return ret.replace(tzinfo=None)  # return datetime object and not string
+                # NOTE this is not a full ISO 8601 format, but it's enough for our needs
+                # return ret.strftime('%Y-%m-%dT%H:%M:%S') + ret.strftime('.%f')[:4] + 'Z'
+            return int(ret.timestamp())
+        return ""
 
     return func
 
 
 @pytest.fixture
-def context(vcr, unique, freezer):
+def context(vcr, unique, freezed_time):
     """
     Return a mapping with all defined fixtures, all objects created by `given` steps,
     and the undo operations to perform after a test scenario.
@@ -244,8 +250,8 @@ def context(vcr, unique, freezer):
         "unique_alnum": PATTERN_ALPHANUM.sub("", unique),
         "unique_lower_alnum": PATTERN_ALPHANUM.sub("", unique).lower(),
         "unique_upper_alnum": PATTERN_ALPHANUM.sub("", unique).upper(),
-        "timestamp": relative_time(freezer, False),
-        "timeISO": relative_time(freezer, True),
+        "timestamp": relative_time(freezed_time, False),
+        "timeISO": relative_time(freezed_time, True),
     }
 
     yield ctx
@@ -278,7 +284,7 @@ def vcr_config():
     if tracer:
         from urllib.parse import urlparse
 
-        config["ignore_hosts"] = [urlparse(tracer.writer.agent_url).hostname]
+        config["ignore_hosts"] = [urlparse(tracer._writer.agent_url).hostname]
 
     return config
 
@@ -289,8 +295,7 @@ def default_cassette_name(default_cassette_name):
 
 
 @pytest.fixture
-def freezer(default_cassette_name, record_mode, vcr):
-    from freezegun import freeze_time
+def freezed_time(default_cassette_name, record_mode, vcr):
     from dateutil import parser
 
     if record_mode in {"new_episodes", "rewrite"}:
@@ -318,7 +323,7 @@ def freezer(default_cassette_name, record_mode, vcr):
             )
             raise RuntimeError(msg)
 
-    return freeze_time(parser.isoparse(freeze_at))
+    return parser.isoparse(freeze_at)
 
 
 def pytest_recording_configure(config, vcr):
@@ -354,11 +359,6 @@ def package_name(api_version):
     return "datadog_api_client." + api_version
 
 
-@pytest.fixture
-def _package(package_name):
-    return importlib.import_module(package_name)
-
-
 @pytest.fixture(scope="module")
 def undo_operations():
     result = {}
@@ -373,8 +373,8 @@ def undo_operations():
     return result
 
 
-def build_configuration(package):
-    c = package.Configuration()
+def build_configuration():
+    c = Configuration()
     c.connection_pool_maxsize = 0
     c.debug = debug = os.getenv("DEBUG") in {"true", "1", "yes", "on"}
     if debug:  # enable vcr logs for DEBUG=true
@@ -387,13 +387,13 @@ def build_configuration(package):
 
 
 @pytest.fixture
-def configuration(_package):
-    return build_configuration(_package)
+def configuration():
+    return build_configuration()
 
 
 @pytest.fixture
-def client(_package, context, configuration):
-    with _package.ApiClient(configuration) as api_client:
+def client(configuration):
+    with ApiClient(configuration) as api_client:
         yield api_client
 
 
@@ -476,7 +476,7 @@ def build_given(version, operation):
         package_name = f"datadog_api_client.{version}"
 
         # make sure we have a fresh instance of API client and configuration
-        configuration = build_configuration(importlib.import_module(package_name))
+        configuration = build_configuration()
         configuration.api_key["apiKeyAuth"] = os.getenv("DD_TEST_CLIENT_API_KEY", "fake")
         configuration.api_key["appKeyAuth"] = os.getenv("DD_TEST_CLIENT_APP_KEY", "fake")
 
@@ -485,7 +485,7 @@ def build_given(version, operation):
             configuration.unstable_operations[operation_name] = True
 
         package = importlib.import_module(f"{package_name}.api.{module_name}_api")
-        with package.ApiClient(configuration) as client:
+        with ApiClient(configuration) as client:
             api = getattr(package, name + "Api")(client)
             operation_method = getattr(api, operation_name)
 
@@ -528,7 +528,6 @@ for f in pathlib.Path(os.path.dirname(__file__)).rglob("given.json"):
 @pytest.fixture
 def undo(package_name, undo_operations, client):
     """Clean after operation."""
-    exceptions = importlib.import_module(package_name + ".exceptions")
 
     def cleanup(api, version, operation_id, response, client=client):
         operation = undo_operations.get(version, {}).get(operation_id)
@@ -566,15 +565,14 @@ def undo(package_name, undo_operations, client):
 
 
 @when("the request is sent")
-def execute_request(undo, context, client, api_version, _package):
+def execute_request(undo, context, client, api_version):
     """Execute the prepared request."""
     api_request = context["api_request"]
-    exceptions = importlib.import_module(context["api"]["package"] + ".exceptions")
 
     try:
         response = api_request["request"](*api_request["args"], **api_request["kwargs"])
         # Reserialise the response body to JSON to facilitate test assertions
-        response_body_json = _package.api_client.ApiClient.sanitize_for_serialization(response[0])
+        response_body_json = client.sanitize_for_serialization(response[0])
         api_request["response"] = [response_body_json, response[1], response[2]]
     except exceptions.ApiException as e:
         # If we have an exception, make a stub response object to use for assertions
@@ -590,6 +588,26 @@ def execute_request(undo, context, client, api_version, _package):
     context["undo_operations"].append(lambda: undo(api, api_version, operation_id, response))
 
 
+@when("the request with pagination is sent")
+def execute_request_with_pagination(undo, context, client, api_version):
+    """Execute the prepared paginated request."""
+    api_request = context["api_request"]
+
+    kwargs = api_request["kwargs"]
+    kwargs["_return_http_data_only"] = True
+    method = getattr(api_request["api"], f"{api_request['request'].__name__}_with_pagination")
+    try:
+        response = list(method(*api_request["args"], **kwargs))
+        # Reserialise the response body to JSON to facilitate test assertions
+        response_body_json = client.sanitize_for_serialization(response)
+        api_request["response"] = [response_body_json, 200, None]
+    except exceptions.ApiException as e:
+        # If we have an exception, make a stub response object to use for assertions
+        # Instead of finding the response class of the method, we use the fact that all
+        # responses returned have an ordered response of body|status|headers
+        api_request["response"] = [e.body, e.status, e.headers]
+
+
 @then(parsers.parse("the response status is {status:d} {description}"))
 def the_status_is(context, status, description):
     """Check the status."""
@@ -616,6 +634,12 @@ def expect_equal_length(context, response_path, fixture_length):
     assert fixture_length == len(response_value)
 
 
+@then(parsers.parse("the response has {fixture_length:d} items"))
+def expect_equal_response_items(context, fixture_length):
+    response = context["api_request"]["response"][0]
+    assert fixture_length == len(response)
+
+
 @then(parsers.parse('the response "{response_path}" is false'))
 def expect_false(context, response_path):
     response_value = glom(context["api_request"]["response"][0], response_path)
